@@ -15,14 +15,15 @@
 
 #include "command_p.h"
 
-#include "exportopenpgpcertstoservercommand.h"
 #include "dialogs/certifycertificatedialog.h"
-#include "utils/keys.h"
+#include "exportopenpgpcertstoservercommand.h"
 #include "utils/tags.h"
 
 #include <Libkleo/Algorithm>
-#include <Libkleo/KeyCache>
+#include <Libkleo/Compat>
 #include <Libkleo/Formatting>
+#include <Libkleo/KeyCache>
+#include <Libkleo/KeyHelpers>
 
 #include <QGpgME/Protocol>
 #include <QGpgME/SignKeyJob>
@@ -47,6 +48,7 @@ class CertifyCertificateCommand::Private : public Command::Private
     {
         return static_cast<CertifyCertificateCommand *>(q);
     }
+
 public:
     explicit Private(CertifyCertificateCommand *qq, KeyListController *c);
     ~Private() override;
@@ -82,10 +84,10 @@ const CertifyCertificateCommand::Private *CertifyCertificateCommand::d_func() co
 #define q q_func()
 
 CertifyCertificateCommand::Private::Private(CertifyCertificateCommand *qq, KeyListController *c)
-    : Command::Private(qq, c),
-      uids(),
-      dialog(),
-      job()
+    : Command::Private(qq, c)
+    , uids()
+    , dialog()
+    , job()
 {
 }
 
@@ -142,8 +144,7 @@ CertifyCertificateCommand::~CertifyCertificateCommand()
 void CertifyCertificateCommand::doStart()
 {
     const std::vector<Key> keys = d->keys();
-    if (keys.size() != 1 ||
-            keys.front().protocol() != GpgME::OpenPGP) {
+    if (keys.size() != 1 || keys.front().protocol() != GpgME::OpenPGP) {
         d->finished();
         return;
     }
@@ -163,8 +164,7 @@ void CertifyCertificateCommand::doStart()
     auto findAnyGoodKey = []() {
         const std::vector<Key> secKeys = KeyCache::instance()->secretKeys();
         return std::any_of(secKeys.cbegin(), secKeys.cend(), [](const Key &secKey) {
-            return secKey.canCertify() && secKey.protocol() == OpenPGP && !secKey.isRevoked()
-                   && !secKey.isExpired() && !secKey.isInvalid();
+            return Kleo::keyHasCertify(secKey) && secKey.protocol() == OpenPGP && !secKey.isRevoked() && !secKey.isExpired() && !secKey.isInvalid();
         });
     };
 
@@ -173,7 +173,7 @@ void CertifyCertificateCommand::doStart()
             KMessageBox::questionTwoActions(d->parentWidgetOrView(),
                                             xi18nc("@info", "To certify other certificates, you first need to create an OpenPGP certificate for yourself.")
                                                 + QStringLiteral("<br><br>") + i18n("Do you wish to create one now?"),
-                                            i18n("Certification Not Possible"),
+                                            i18nc("@title:window", "Certification Not Possible"),
                                             KGuiItem(i18n("Create")),
                                             KStandardGuiItem::cancel());
         if (sel == KMessageBox::ButtonCode::PrimaryAction) {
@@ -211,13 +211,7 @@ void CertifyCertificateCommand::doStart()
     d->ensureDialogCreated();
     Q_ASSERT(d->dialog);
 
-    if (!(d->target.keyListMode() & GpgME::SignatureNotations)) {
-        d->target.update();
-    }
-    d->dialog->setCertificateToCertify(d->target);
-    if (d->uids.size()) {
-        d->dialog->setSelectedUserIDs(d->uids);
-    }
+    d->dialog->setCertificateToCertify(d->target, d->uids);
     d->dialog->show();
 }
 
@@ -234,15 +228,14 @@ void CertifyCertificateCommand::Private::slotResult(const Error &err)
     } else if (err) {
         error(i18n("<p>An error occurred while trying to certify<br/><br/>"
                    "<b>%1</b>:</p><p>\t%2</p>",
-              Formatting::formatForComboBox(target),
-              Formatting::errorAsString(err)),
+                   Formatting::formatForComboBox(target),
+                   Formatting::errorAsString(err)),
               i18n("Certification Error"));
     } else if (dialog && dialog->exportableCertificationSelected() && dialog->sendToServer()) {
         auto const cmd = new ExportOpenPGPCertsToServerCommand(target);
         cmd->start();
     } else {
-        information(i18n("Certification successful."),
-                    i18n("Certification Succeeded"));
+        information(i18n("Certification successful."), i18n("Certification Succeeded"));
     }
 
     if (!dialog->tags().isEmpty()) {
@@ -271,7 +264,6 @@ void CertifyCertificateCommand::Private::slotCertificationPrepared()
     createJob();
     Q_ASSERT(job);
     job->setExportable(dialog->exportableCertificationSelected());
-    job->setNonRevocable(dialog->nonRevocableCertificationSelected());
     job->setUserIDsToSign(userIdIndexes);
     job->setSigningKey(dialog->selectedSecretKey());
     if (!dialog->tags().isEmpty()) {
@@ -309,8 +301,12 @@ void CertifyCertificateCommand::Private::ensureDialogCreated()
     dialog = new CertifyCertificateDialog;
     applyWindowID(dialog);
 
-    connect(dialog, &QDialog::rejected, q, [this]() { slotDialogRejected(); });
-    connect(dialog, &QDialog::accepted, q, [this]() { slotCertificationPrepared(); });
+    connect(dialog, &QDialog::rejected, q, [this]() {
+        slotDialogRejected();
+    });
+    connect(dialog, &QDialog::accepted, q, [this]() {
+        slotCertificationPrepared();
+    });
 }
 
 void CertifyCertificateCommand::Private::createJob()
@@ -328,14 +324,10 @@ void CertifyCertificateCommand::Private::createJob()
         return;
     }
 
-#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
-    connect(j, &QGpgME::Job::jobProgress,
-            q, &Command::progress);
-#else
-    connect(j, &QGpgME::Job::progress,
-            q, [this](const QString &, int current, int total) { Q_EMIT q->progress(current, total); });
-#endif
-    connect(j, &SignKeyJob::result, q, [this](const GpgME::Error &result) { slotResult(result); });
+    connect(j, &QGpgME::Job::jobProgress, q, &Command::progress);
+    connect(j, &SignKeyJob::result, q, [this](const GpgME::Error &result) {
+        slotResult(result);
+    });
 
     job = j;
 }
