@@ -12,6 +12,8 @@
 #include "importcertificatefromfilecommand.h"
 #include "importcertificatescommand_p.h"
 
+#include <kleopatra_debug.h>
+
 #include <QGpgME/Protocol>
 
 #include <Libkleo/Classify>
@@ -19,15 +21,16 @@
 #include <gpgme++/global.h>
 #include <gpgme++/importresult.h>
 
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
+#include <QDir>
 #include <QFile>
 #include <QFileDialog>
-#include <QString>
-#include <QWidget>
 #include <QFileInfo>
-#include <QDir>
+#include <QString>
+#include <QTextCodec>
+#include <QWidget>
 
 #include <KSharedConfig>
 
@@ -44,6 +47,7 @@ class ImportCertificateFromFileCommand::Private : public ImportCertificatesComma
     {
         return static_cast<ImportCertificateFromFileCommand *>(q);
     }
+
 public:
     explicit Private(ImportCertificateFromFileCommand *qq, KeyListController *c);
     ~Private() override;
@@ -64,13 +68,14 @@ const ImportCertificateFromFileCommand::Private *ImportCertificateFromFileComman
 }
 
 ImportCertificateFromFileCommand::Private::Private(ImportCertificateFromFileCommand *qq, KeyListController *c)
-    : ImportCertificatesCommand::Private(qq, c),
-      files()
+    : ImportCertificatesCommand::Private(qq, c)
+    , files()
 {
-
 }
 
-ImportCertificateFromFileCommand::Private::~Private() {}
+ImportCertificateFromFileCommand::Private::~Private()
+{
+}
 
 #define d d_func()
 #define q q_func()
@@ -78,19 +83,16 @@ ImportCertificateFromFileCommand::Private::~Private() {}
 ImportCertificateFromFileCommand::ImportCertificateFromFileCommand()
     : ImportCertificatesCommand(new Private(this, nullptr))
 {
-
 }
 
 ImportCertificateFromFileCommand::ImportCertificateFromFileCommand(KeyListController *p)
     : ImportCertificatesCommand(new Private(this, p))
 {
-
 }
 
 ImportCertificateFromFileCommand::ImportCertificateFromFileCommand(QAbstractItemView *v, KeyListController *p)
     : ImportCertificatesCommand(v, new Private(this, p))
 {
-
 }
 
 ImportCertificateFromFileCommand::ImportCertificateFromFileCommand(const QStringList &files, KeyListController *p)
@@ -105,7 +107,9 @@ ImportCertificateFromFileCommand::ImportCertificateFromFileCommand(const QString
     d->files = files;
 }
 
-ImportCertificateFromFileCommand::~ImportCertificateFromFileCommand() {}
+ImportCertificateFromFileCommand::~ImportCertificateFromFileCommand()
+{
+}
 
 void ImportCertificateFromFileCommand::setFiles(const QStringList &files)
 {
@@ -121,20 +125,25 @@ void ImportCertificateFromFileCommand::doStart()
     }
 
     d->setProgressWindowTitle(i18nc("@title:window", "Importing Certificates"));
-    d->setProgressLabelText(i18np("Importing certificates from 1 file...",
-                                  "Importing certificates from %1 files...",
-                                  d->files.size()));
+    d->setProgressLabelText(i18np("Importing certificates from 1 file...", "Importing certificates from %1 files...", d->files.size()));
 
-    //TODO: use KIO here
+    // TODO: use KIO here
     d->setWaitForMoreJobs(true);
     for (const QString &fn : std::as_const(d->files)) {
         QFile in(fn);
         if (!in.open(QIODevice::ReadOnly)) {
             d->error(i18n("Could not open file %1 for reading: %2", in.fileName(), in.errorString()), i18n("Certificate Import Failed"));
-            d->importResult({fn, GpgME::UnknownProtocol, ImportType::Local, ImportResult{}});
+            d->addImportResult({fn, GpgME::UnknownProtocol, ImportType::Local, ImportResult{}, AuditLogEntry{}});
             continue;
         }
-        const auto data = in.readAll();
+        auto data = in.readAll();
+        // check for UTF-16- (or UTF-32- or UTF-8-with-BOM-)encoded text file;
+        // binary certificate files don't start with a BOM, so that it's safe
+        // to assume that data starting with a BOM is UTF-encoded text
+        if (const auto codec = QTextCodec::codecForUtfText(data, nullptr)) {
+            qCDebug(KLEOPATRA_LOG) << this << __func__ << "Decoding" << codec->name() << "encoded data";
+            data = codec->toUnicode(data).toUtf8();
+        }
         d->startImport(GpgME::OpenPGP, data, fn);
         d->startImport(GpgME::CMS, data, fn);
         d->importGroupsFromFile(fn);
@@ -148,13 +157,14 @@ static QStringList get_file_name(QWidget *parent)
     const QString anyFilesFilter = i18n("Any files") + QLatin1String(" (*)");
     QString previousDir;
     if (const KSharedConfig::Ptr config = KSharedConfig::openConfig()) {
-        const KConfigGroup group(config, "Import Certificate");
+        const KConfigGroup group(config, QStringLiteral("Import Certificate"));
         previousDir = group.readPathEntry("last-open-file-directory", QDir::homePath());
     }
-    const QStringList files = QFileDialog::getOpenFileNames(parent, i18n("Select Certificate File"), previousDir, certificateFilter + QLatin1String(";;") + anyFilesFilter);
+    const QStringList files =
+        QFileDialog::getOpenFileNames(parent, i18n("Select Certificate File"), previousDir, certificateFilter + QLatin1String(";;") + anyFilesFilter);
     if (!files.empty())
         if (const KSharedConfig::Ptr config = KSharedConfig::openConfig()) {
-            KConfigGroup group(config, "Import Certificate");
+            KConfigGroup group(config, QStringLiteral("Import Certificate"));
             group.writePathEntry("last-open-file-directory", QFileInfo(files.front()).path());
         }
     return files;
@@ -171,3 +181,4 @@ bool ImportCertificateFromFileCommand::Private::ensureHaveFile()
 #undef d
 #undef q
 
+#include "moc_importcertificatefromfilecommand.cpp"
