@@ -20,11 +20,9 @@
 #include <gpgme++/global.h>
 #include <gpgme++/importresult.h>
 
-#if QGPGME_SUPPORTS_DEFERRED_IMPORT_JOB
-#include <queue>
-#endif
-#include <vector>
 #include <map>
+#include <queue>
+#include <vector>
 
 namespace GpgME
 {
@@ -46,15 +44,13 @@ class KeyCacheAutoRefreshSuspension;
 class QByteArray;
 class QProgressDialog;
 
-enum class ImportType
-{
+enum class ImportType {
     Unknown,
     Local,
     External,
 };
 
-struct ImportJobData
-{
+struct ImportJobData {
     QString id;
     GpgME::Protocol protocol = GpgME::UnknownProtocol;
     ImportType type = ImportType::Unknown;
@@ -64,8 +60,7 @@ struct ImportJobData
 
 bool operator==(const ImportJobData &lhs, const ImportJobData &rhs);
 
-struct ImportResultData
-{
+struct ImportResultData {
     QString id;
     GpgME::Protocol protocol = GpgME::UnknownProtocol;
     ImportType type = ImportType::Unknown;
@@ -73,10 +68,8 @@ struct ImportResultData
     Kleo::AuditLogEntry auditLog;
 };
 
-struct ImportedGroup
-{
-    enum class Status
-    {
+struct ImportedGroup {
+    enum class Status {
         New,
         Updated,
     };
@@ -85,8 +78,7 @@ struct ImportedGroup
     Status status;
 };
 
-struct ImportOptions
-{
+struct ImportOptions {
     QString importFilter;
     GpgME::Key::Origin keyOrigin = GpgME::Key::OriginUnknown;
     QString keyOriginUrl;
@@ -122,13 +114,10 @@ public:
 
     bool showPleaseCertify(const GpgME::Import &imp);
 
-    void keyListDone(const GpgME::KeyListResult &result,
-                     const std::vector<GpgME::Key> &keys,
-                     const QString &, const GpgME::Error&);
+    void keyListDone(const GpgME::KeyListResult &result, const std::vector<GpgME::Key> &keys, const QString &, const GpgME::Error &);
 
 private:
-    void showDetails(const std::vector<ImportResultData> &results,
-                     const std::vector<ImportedGroup> &groups);
+    void showDetails(const std::vector<ImportResultData> &results, const std::vector<ImportedGroup> &groups);
     void processResults();
     void tryToFinish();
     void keyCacheUpdated();
@@ -145,9 +134,7 @@ private:
     bool waitForMoreJobs = false;
     bool importingSignerKeys = false;
     std::vector<GpgME::Protocol> nonWorkingProtocols;
-#if QGPGME_SUPPORTS_DEFERRED_IMPORT_JOB
     std::queue<ImportJobData> pendingJobs;
-#endif
     std::vector<ImportJobData> runningJobs;
     std::vector<QString> filesToImportGroupsFrom;
     std::vector<ImportResultData> results;
@@ -169,7 +156,11 @@ inline const Kleo::ImportCertificatesCommand::Private *Kleo::ImportCertificatesC
     return static_cast<const Private *>(d.get());
 }
 
-inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(Private *pp) : Command(pp) {}
-inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(QAbstractItemView *v, Private *pp) : Command(v, pp) {}
-
-
+inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(Private *pp)
+    : Command(pp)
+{
+}
+inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(QAbstractItemView *v, Private *pp)
+    : Command(v, pp)
+{
+}
