@@ -17,8 +17,8 @@
 #include "settings.h"
 
 #include <KConfig>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 
 #include "conf/appearanceconfigpage.h"
@@ -76,7 +76,7 @@ ConfigureDialog::ConfigureDialog(QWidget *parent)
     // the KCMultiDialog starts with the size of the first kcm, not
     // the largest one. This way at least after the first showing of
     // the largest kcm the size is kept.
-    const KConfigGroup geometry(KSharedConfig::openStateConfig(), "Geometry");
+    const KConfigGroup geometry(KSharedConfig::openStateConfig(), QStringLiteral("Geometry"));
     const int width = geometry.readEntry("ConfigureDialogWidth", 0);
     const int height = geometry.readEntry("ConfigureDialogHeight", 0);
     if (width != 0 && height != 0) {
@@ -87,7 +87,7 @@ ConfigureDialog::ConfigureDialog(QWidget *parent)
 void ConfigureDialog::hideEvent(QHideEvent *e)
 {
     const QSize minSize = minimumSizeHint();
-    KConfigGroup geometry(KSharedConfig::openStateConfig(), "Geometry");
+    KConfigGroup geometry(KSharedConfig::openStateConfig(), QStringLiteral("Geometry"));
     geometry.writeEntry("ConfigureDialogWidth", minSize.width());
     geometry.writeEntry("ConfigureDialogHeight", minSize.height());
     KleoPageConfigDialog::hideEvent(e);
@@ -96,3 +96,5 @@ void ConfigureDialog::hideEvent(QHideEvent *e)
 ConfigureDialog::~ConfigureDialog()
 {
 }
+
+#include "moc_configuredialog.cpp"
