@@ -10,12 +10,14 @@
 
 #include "groupsconfigwidget.h"
 
-#include "commands/exportgroupscommand.h"
-#include "dialogs/editgroupdialog.h"
+#include <commands/certifygroupcommand.h>
+#include <commands/exportgroupscommand.h>
+#include <dialogs/editgroupdialog.h>
 
 #include <Libkleo/Debug>
 #include <Libkleo/KeyCache>
 #include <Libkleo/KeyGroup>
+#include <Libkleo/KeyHelpers>
 #include <Libkleo/KeyListModel>
 #include <Libkleo/KeyListSortFilterProxyModel>
 
@@ -104,8 +106,7 @@ public:
     }
 };
 
-struct Selection
-{
+struct Selection {
     KeyGroup current;
     std::vector<KeyGroup> selected;
 };
@@ -123,6 +124,7 @@ class GroupsConfigWidget::Private
         QPushButton *newButton = nullptr;
         QPushButton *editButton = nullptr;
         QPushButton *deleteButton = nullptr;
+        QPushButton *certifyButton = nullptr;
         QPushButton *exportButton = nullptr;
     } ui;
     AbstractKeyListModel *groupsModel = nullptr;
@@ -177,18 +179,23 @@ public:
 
         auto groupsButtonLayout = new QVBoxLayout;
 
-        ui.newButton = new QPushButton(i18nc("@action::button", "New"), q);
+        ui.newButton = new QPushButton(i18nc("@action:button", "New"), q);
         groupsButtonLayout->addWidget(ui.newButton);
 
-        ui.editButton = new QPushButton(i18nc("@action::button", "Edit"), q);
+        ui.editButton = new QPushButton(i18nc("@action:button", "Edit"), q);
         ui.editButton->setEnabled(false);
         groupsButtonLayout->addWidget(ui.editButton);
 
-        ui.deleteButton = new QPushButton(i18nc("@action::button", "Delete"), q);
+        ui.deleteButton = new QPushButton(i18nc("@action:button", "Delete"), q);
         ui.deleteButton->setEnabled(false);
         groupsButtonLayout->addWidget(ui.deleteButton);
 
-        ui.exportButton = new QPushButton{i18nc("@action::button", "Export"), q};
+        ui.certifyButton = new QPushButton{i18nc("@action:button", "Certify"), q};
+        ui.certifyButton->setToolTip(i18nc("@info:tooltip", "Start the certification process for all certificates in the group."));
+        ui.certifyButton->setEnabled(false);
+        groupsButtonLayout->addWidget(ui.certifyButton);
+
+        ui.exportButton = new QPushButton{i18nc("@action:button", "Export"), q};
         ui.exportButton->setEnabled(false);
         groupsButtonLayout->addWidget(ui.exportButton);
 
@@ -196,19 +203,32 @@ public:
 
         groupsLayout->addLayout(groupsButtonLayout, row, 1);
 
-        mainLayout->addLayout(groupsLayout, /*stretch=*/ 1);
+        mainLayout->addLayout(groupsLayout, /*stretch=*/1);
 
         connect(ui.groupsFilter, &QLineEdit::textChanged, q, [this](const auto &s) {
             groupsFilterModel->setFilterRegularExpression(QRegularExpression::escape(s));
         });
-        connect(ui.groupsList->selectionModel(), &QItemSelectionModel::selectionChanged,
-                q, [this] () { selectionChanged(); });
-        connect(ui.groupsList, &QListView::doubleClicked,
-                q, [this] (const QModelIndex &index) { editGroup(index); });
-        connect(ui.newButton, &QPushButton::clicked, q, [this] () { addGroup(); });
-        connect(ui.editButton, &QPushButton::clicked, q, [this] () { editGroup(); });
-        connect(ui.deleteButton, &QPushButton::clicked, q, [this] () { deleteGroup(); });
-        connect(ui.exportButton, &QPushButton::clicked, q, [this] () { exportGroup(); });
+        connect(ui.groupsList->selectionModel(), &QItemSelectionModel::selectionChanged, q, [this]() {
+            selectionChanged();
+        });
+        connect(ui.groupsList, &QListView::doubleClicked, q, [this](const QModelIndex &index) {
+            editGroup(index);
+        });
+        connect(ui.newButton, &QPushButton::clicked, q, [this]() {
+            addGroup();
+        });
+        connect(ui.editButton, &QPushButton::clicked, q, [this]() {
+            editGroup();
+        });
+        connect(ui.deleteButton, &QPushButton::clicked, q, [this]() {
+            deleteGroup();
+        });
+        connect(ui.certifyButton, &QPushButton::clicked, q, [this]() {
+            certifyGroup();
+        });
+        connect(ui.exportButton, &QPushButton::clicked, q, [this]() {
+            exportGroup();
+        });
     }
 
     ~Private()
@@ -238,9 +258,9 @@ private:
     auto getGroups(const QModelIndexList &indexes)
     {
         std::vector<KeyGroup> groups;
-        std::transform(std::begin(indexes), std::end(indexes),
-                       std::back_inserter(groups),
-                       [this](const auto &index) { return getGroup(index); });
+        std::transform(std::begin(indexes), std::end(indexes), std::back_inserter(groups), [this](const auto &index) {
+            return getGroup(index);
+        });
         return groups;
     }
 
@@ -266,11 +286,14 @@ private:
     void selectionChanged()
     {
         const auto selectedGroups = getGroups(selectedRows());
-        const bool allSelectedGroupsAreEditable =
-            std::all_of(std::begin(selectedGroups), std::end(selectedGroups),
-                        [](const auto &g) { return !g.isNull() && !g.isImmutable(); });
+        const bool allSelectedGroupsAreEditable = std::all_of(std::begin(selectedGroups), std::end(selectedGroups), [](const auto &g) {
+            return !g.isNull() && !g.isImmutable();
+        });
         ui.editButton->setEnabled(selectedGroups.size() == 1 && allSelectedGroupsAreEditable);
         ui.deleteButton->setEnabled(!selectedGroups.empty() && allSelectedGroupsAreEditable);
+        ui.certifyButton->setEnabled(selectedGroups.size() == 1 //
+                                     && !selectedGroups.front().keys().empty() //
+                                     && allKeysHaveProtocol(selectedGroups.front().keys(), GpgME::OpenPGP));
         ui.exportButton->setEnabled(selectedGroups.size() == 1);
     }
 
@@ -300,8 +323,7 @@ private:
         KeyGroup group = KeyGroup(newId, i18nc("default name for new group of keys", "New Group"), {}, KeyGroup::ApplicationConfig);
         group.setIsImmutable(false);
 
-        const KeyGroup newGroup = showEditGroupDialog(
-            group, i18nc("@title:window a group of keys", "New Group"), EditGroupDialog::GroupName);
+        const KeyGroup newGroup = showEditGroupDialog(group, i18nc("@title:window a group of keys", "New Group"), EditGroupDialog::GroupName);
         if (newGroup.isNull()) {
             return;
         }
@@ -338,8 +360,7 @@ private:
             return;
         }
 
-        const KeyGroup updatedGroup = showEditGroupDialog(
-            group, i18nc("@title:window a group of keys", "Edit Group"), EditGroupDialog::KeysFilter);
+        const KeyGroup updatedGroup = showEditGroupDialog(group, i18nc("@title:window a group of keys", "Edit Group"), EditGroupDialog::KeysFilter);
         if (updatedGroup.isNull()) {
             return;
         }
@@ -377,6 +398,20 @@ private:
         Q_EMIT q->changed();
     }
 
+    void certifyGroup()
+    {
+        const auto selectedGroups = getGroups(selectedRows());
+        if (selectedGroups.size() != 1) {
+            qCDebug(KLEOPATRA_LOG) << __func__ << (selectedGroups.empty() ? "selection is empty" : "more than one group is selected");
+            return;
+        }
+
+        // execute export group command
+        auto cmd = new CertifyGroupCommand{selectedGroups.front()};
+        cmd->setParentWidget(q->window());
+        cmd->start();
+    }
+
     void exportGroup()
     {
         const auto selectedGroups = getGroups(selectedRows());
@@ -418,3 +453,5 @@ std::vector<KeyGroup> GroupsConfigWidget::groups() const
 }
 
 #include "groupsconfigwidget.moc"
+
+#include "moc_groupsconfigwidget.cpp"
