@@ -7,8 +7,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
-#include <kcmutils_version.h>
 #include <KCModule>
+#include <kcmutils_version.h>
 namespace Kleo
 {
 namespace Config
@@ -20,20 +20,15 @@ class SMimeValidationConfigurationPage : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit SMimeValidationConfigurationPage(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit SMimeValidationConfigurationPage(QObject *parent, const KPluginMetaData &data = {}, const QVariantList &args = QVariantList());
-#endif
-public Q_SLOTS:
+    explicit SMimeValidationConfigurationPage(QObject *parent, const KPluginMetaData &data = {});
+
     void load() override;
     void save() override;
     void defaults() override;
 
 private:
-    SMimeValidationConfigurationWidget *mWidget;
+    SMimeValidationConfigurationWidget *mWidget = nullptr;
 };
 
 }
 }
-
