@@ -32,60 +32,11 @@ using namespace GpgME;
 using namespace KMime::Types;
 using namespace KMime::HeaderParsing;
 
-std::vector< std::vector<Key> > CertificateResolver::resolveRecipients(const std::vector<Mailbox> &recipients, Protocol proto)
-{
-    std::vector< std::vector<Key> > result;
-    std::transform(recipients.begin(), recipients.end(),
-                   std::back_inserter(result), 
-                   [proto](const Mailbox &recipient) {
-                       return resolveRecipient(recipient, proto);
-                   });
-    return result;
-}
-
-std::vector<Key> CertificateResolver::resolveRecipient(const Mailbox &recipient, Protocol proto)
-{
-    std::vector<Key> result = KeyCache::instance()->findByEMailAddress(recipient.address().constData());
-    auto end = std::remove_if(result.begin(), result.end(),
-                              [](const Key &key) { return key.canEncrypt(); });
-
-    if (proto != UnknownProtocol)
-        end = std::remove_if(result.begin(), end,
-                             [proto](const Key &key) { return key.protocol() != proto; });
-
-    result.erase(end, result.end());
-    return result;
-}
-
-std::vector< std::vector<Key> > CertificateResolver::resolveSigners(const std::vector<Mailbox> &signers, Protocol proto)
-{
-    std::vector< std::vector<Key> > result;
-    std::transform(signers.begin(), signers.end(),
-                   std::back_inserter(result),
-                   [proto](const Mailbox &signer) {
-                       return resolveSigner(signer, proto);
-                   });
-    return result;
-}
-
-std::vector<Key> CertificateResolver::resolveSigner(const Mailbox &signer, Protocol proto)
-{
-    std::vector<Key> result = KeyCache::instance()->findByEMailAddress(signer.address().constData());
-    auto end = std::remove_if(result.begin(), result.end(),
-                              [](const Key &key) { return key.hasSecret(); });
-    end = std::remove_if(result.begin(), end,
-                         [](const Key &key) { return key.canReallySign(); });
-    if (proto != UnknownProtocol)
-        end = std::remove_if(result.begin(), end,
-                             [proto](const Key &key) { return key.protocol() != proto; });
-    result.erase(end, result.end());
-    return result;
-}
-
 class KConfigBasedRecipientPreferences::Private
 {
     friend class ::Kleo::Crypto::KConfigBasedRecipientPreferences;
     KConfigBasedRecipientPreferences *const q;
+
 public:
     explicit Private(const KSharedConfigPtr &config, KConfigBasedRecipientPreferences *qq);
     ~Private();
@@ -103,8 +54,13 @@ private:
     mutable bool m_dirty;
 };
 
-KConfigBasedRecipientPreferences::Private::Private(const KSharedConfigPtr &config, KConfigBasedRecipientPreferences *qq) : q(qq), m_config(config), m_parsed(false), m_dirty(false)
+KConfigBasedRecipientPreferences::Private::Private(const KSharedConfigPtr &config, KConfigBasedRecipientPreferences *qq)
+    : q(qq)
+    , m_config(config)
+    , m_parsed(false)
+    , m_dirty(false)
 {
+    Q_UNUSED(q);
     Q_ASSERT(m_config);
 }
 
@@ -122,7 +78,6 @@ void KConfigBasedRecipientPreferences::Private::writePrefs()
     const auto cmsPrefsKeys = cmsPrefs.keys();
     const QSet<QByteArray> keys = QSet<QByteArray>(pgpPrefsKeys.begin(), pgpPrefsKeys.end()) + QSet<QByteArray>(cmsPrefsKeys.begin(), cmsPrefsKeys.end());
 
-
     int n = 0;
     for (const QByteArray &i : keys) {
         KConfigGroup group(m_config, QStringLiteral("EncryptionPreference_%1").arg(n++));
@@ -158,7 +113,8 @@ void KConfigBasedRecipientPreferences::Private::ensurePrefsParsed() const
     m_parsed = true;
 }
 
-KConfigBasedRecipientPreferences::KConfigBasedRecipientPreferences(const KSharedConfigPtr &config) : d(new Private(config, this))
+KConfigBasedRecipientPreferences::KConfigBasedRecipientPreferences(const KSharedConfigPtr &config)
+    : d(new Private(config, this))
 {
 }
 
@@ -189,6 +145,7 @@ class KConfigBasedSigningPreferences::Private
 {
     friend class ::Kleo::Crypto::KConfigBasedSigningPreferences;
     KConfigBasedSigningPreferences *const q;
+
 public:
     explicit Private(const KSharedConfigPtr &config, KConfigBasedSigningPreferences *qq);
     ~Private();
@@ -206,8 +163,13 @@ private:
     mutable bool m_dirty;
 };
 
-KConfigBasedSigningPreferences::Private::Private(const KSharedConfigPtr &config, KConfigBasedSigningPreferences *qq) : q(qq), m_config(config), m_parsed(false), m_dirty(false)
+KConfigBasedSigningPreferences::Private::Private(const KSharedConfigPtr &config, KConfigBasedSigningPreferences *qq)
+    : q(qq)
+    , m_config(config)
+    , m_parsed(false)
+    , m_dirty(false)
 {
+    Q_UNUSED(q);
     Q_ASSERT(m_config);
 }
 
@@ -216,7 +178,7 @@ void KConfigBasedSigningPreferences::Private::ensurePrefsParsed() const
     if (m_parsed) {
         return;
     }
-    const KConfigGroup group(m_config, "SigningPreferences");
+    const KConfigGroup group(m_config, QStringLiteral("SigningPreferences"));
     pgpSigningCertificate = group.readEntry("pgpSigningCertificate", QByteArray());
     cmsSigningCertificate = group.readEntry("cmsSigningCertificate", QByteArray());
     m_parsed = true;
@@ -227,7 +189,7 @@ void KConfigBasedSigningPreferences::Private::writePrefs()
     if (!m_dirty) {
         return;
     }
-    KConfigGroup group(m_config, "SigningPreferences");
+    KConfigGroup group(m_config, QStringLiteral("SigningPreferences"));
     group.writeEntry("pgpSigningCertificate", pgpSigningCertificate);
     group.writeEntry("cmsSigningCertificate", cmsSigningCertificate);
     m_config->sync();
@@ -239,7 +201,8 @@ KConfigBasedSigningPreferences::Private::~Private()
     writePrefs();
 }
 
-KConfigBasedSigningPreferences::KConfigBasedSigningPreferences(const KSharedConfigPtr &config) : d(new Private(config, this))
+KConfigBasedSigningPreferences::KConfigBasedSigningPreferences(const KSharedConfigPtr &config)
+    : d(new Private(config, this))
 {
 }
 
@@ -263,4 +226,3 @@ void KConfigBasedSigningPreferences::setPreferredCertificate(Protocol protocol,
     (protocol == CMS ? d->cmsSigningCertificate : d->pgpSigningCertificate) = certificate.keyID();
     d->m_dirty = true;
 }
-
