@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_VERIFYCHECKSUMSDIALOG_H__
-#define __KLEOPATRA_CRYPTO_GUI_VERIFYCHECKSUMSDIALOG_H__
+#pragma once
 
 #include <QDialog>
 #include <QMetaType>
@@ -30,14 +29,14 @@ class VerifyChecksumsDialog : public QDialog
     Q_ENUMS(Status)
 public:
     explicit VerifyChecksumsDialog(QWidget *parent = nullptr);
-    ~VerifyChecksumsDialog();
+    ~VerifyChecksumsDialog() override;
 
     enum Status {
         Unknown,
         OK,
         Failed,
         Error,
-        NumStatii
+        NumStatii,
     };
 
 public Q_SLOTS:
@@ -62,5 +61,3 @@ private:
 Q_DECLARE_METATYPE(Kleo::Crypto::Gui::VerifyChecksumsDialog::Status)
 
 #endif // QT_NO_DIRMODEL
-
-#endif // __KLEOPATRA_CRYPTO_GUI_RESULTITEMWIDGET_H__
