@@ -40,7 +40,7 @@ CertificateDetailsDialog::~CertificateDetailsDialog()
 
 void CertificateDetailsDialog::readConfig()
 {
-    KConfigGroup dialog(KSharedConfig::openStateConfig(), "CertificateDetailsDialog");
+    KConfigGroup dialog(KSharedConfig::openStateConfig(), QStringLiteral("CertificateDetailsDialog"));
     const QSize size = dialog.readEntry("Size", QSize(730, 280));
     if (size.isValid()) {
         resize(size);
@@ -49,7 +49,7 @@ void CertificateDetailsDialog::readConfig()
 
 void CertificateDetailsDialog::writeConfig()
 {
-    KConfigGroup dialog(KSharedConfig::openStateConfig(), "CertificateDetailsDialog");
+    KConfigGroup dialog(KSharedConfig::openStateConfig(), QStringLiteral("CertificateDetailsDialog"));
     dialog.writeEntry("Size", size());
     dialog.sync();
 }
@@ -58,8 +58,7 @@ namespace
 {
 QString title(const GpgME::Key &key)
 {
-    switch (key.protocol())
-    {
+    switch (key.protocol()) {
     case GpgME::OpenPGP:
         return i18nc("@title:window", "OpenPGP Certificate");
     case GpgME::CMS:
@@ -73,10 +72,12 @@ QString title(const GpgME::Key &key)
 void CertificateDetailsDialog::setKey(const GpgME::Key &key)
 {
     setWindowTitle(title(key));
-    findChild<CertificateDetailsWidget*>()->setKey(key);
+    findChild<CertificateDetailsWidget *>()->setKey(key);
 }
 
 GpgME::Key CertificateDetailsDialog::key() const
 {
-    return findChild<CertificateDetailsWidget*>()->key();
+    return findChild<CertificateDetailsWidget *>()->key();
 }
+
+#include "moc_certificatedetailsdialog.cpp"
