@@ -11,35 +11,35 @@
 #include <view/htmllabel.h>
 
 #include <Libkleo/Compat>
-#include <Libkleo/GnuPG>
 #include <Libkleo/Formatting>
+#include <Libkleo/GnuPG>
 
 #include "kleopatra_debug.h"
 
-#include <QIcon>
-#include <QGridLayout>
 #include <QCheckBox>
-#include <QDialogButtonBox>
+#include <QDateTime>
 #include <QDesktopServices>
+#include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QIcon>
+#include <QLabel>
 #include <QProcess>
 #include <QProgressDialog>
 #include <QPushButton>
-#include <QLabel>
 #include <QUrl>
-#include <QDateTime>
 
+#include <KConfigGroup>
 #include <KIconLoader>
 #include <KLocalizedString>
-#include <KConfigGroup>
-#include <KSharedConfig>
 #include <KMessageBox>
+#include <KSharedConfig>
 
 #include <QGpgME/CryptoConfig>
 #include <QGpgME/Protocol>
 
+#include <gpgme++/error.h>
 #include <gpgme++/gpgmefw.h>
 #include <gpgme++/swdbresult.h>
-#include <gpgme++/error.h>
 
 using namespace Kleo;
 
@@ -71,30 +71,21 @@ void UpdateNotification::forceUpdateCheck(QWidget *parent)
         QStringLiteral("/bye"),
     });
 
-    auto progress = new QProgressDialog(i18n("Searching for updates..."),
-                                        i18n("Cancel"), 0, 0, parent);
+    auto progress = new QProgressDialog(i18n("Searching for updates..."), i18n("Cancel"), 0, 0, parent);
     progress->setMinimumDuration(0);
     progress->show();
 
-    connect(progress, &QProgressDialog::canceled, [ proc] () {
-            proc->kill();
-            qCDebug(KLEOPATRA_LOG) << "Update force canceled. Output:"
-                                   << QString::fromLocal8Bit(proc->readAllStandardOutput())
-                                   << "stderr:"
-                                   << QString::fromLocal8Bit(proc->readAllStandardError());
+    connect(progress, &QProgressDialog::canceled, [proc]() {
+        proc->kill();
+        qCDebug(KLEOPATRA_LOG) << "Update force canceled. Output:" << QString::fromLocal8Bit(proc->readAllStandardOutput())
+                               << "stderr:" << QString::fromLocal8Bit(proc->readAllStandardError());
     });
 
-#if QT_DEPRECATED_SINCE(5, 13)
-    connect(proc, qOverload<int, QProcess::ExitStatus>(&QProcess::finished),
-#else
-    connect(proc, &QProcess::finished,
-#endif
-            [parent, progress, proc](int exitCode, QProcess::ExitStatus exitStatus) {
-            qCDebug(KLEOPATRA_LOG) << "Update force exited with status:" << exitStatus
-                                   << "code:" << exitCode;
-            delete progress;
-            proc->deleteLater();
-            UpdateNotification::checkUpdate(parent, exitStatus == QProcess::NormalExit);
+    connect(proc, &QProcess::finished, [parent, progress, proc](int exitCode, QProcess::ExitStatus exitStatus) {
+        qCDebug(KLEOPATRA_LOG) << "Update force exited with status:" << exitStatus << "code:" << exitCode;
+        delete progress;
+        proc->deleteLater();
+        UpdateNotification::checkUpdate(parent, exitStatus == QProcess::NormalExit);
     });
 
     qCDebug(KLEOPATRA_LOG) << "Starting:" << proc->program() << "args" << proc->arguments();
@@ -105,7 +96,7 @@ void UpdateNotification::forceUpdateCheck(QWidget *parent)
 void UpdateNotification::checkUpdate(QWidget *parent, bool force)
 {
 #ifdef Q_OS_WIN
-    KConfigGroup updatecfg(KSharedConfig::openConfig(), "UpdateNotification");
+    KConfigGroup updatecfg(KSharedConfig::openConfig(), QStringLiteral("UpdateNotification"));
 
     if (updatecfg.readEntry("NeverShow", false) && !force) {
         return;
@@ -117,7 +108,7 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
     // we would have set AllowVersionCheck once and the user
     // explicitly removed that.
     if (force || updatecfg.readEntry("AllowVersionCheckSetOnce", false)) {
-        gpgconf_set_update_check (true);
+        gpgconf_set_update_check(true);
         updatecfg.writeEntry("AllowVersionCheckSetOnce", true);
     }
 
@@ -125,15 +116,12 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
     GpgME::Error err;
     const auto lastshown = updatecfg.readEntry("LastShown", QDateTime());
 
-    if (!force && lastshown.isValid() &&
-        lastshown.addSecs(20 * 60 * 60) > QDateTime::currentDateTime()) {
+    if (!force && lastshown.isValid() && lastshown.addSecs(20 * 60 * 60) > QDateTime::currentDateTime()) {
         qDebug() << QDateTime::currentDateTime().addSecs(20 * 60 * 60);
         return;
     }
 
-    const auto results = GpgME::SwdbResult::query("gpg4win",
-                                                  current.toUtf8().constData(),
-                                                  &err);
+    const auto results = GpgME::SwdbResult::query("gpg4win", current.toUtf8().constData(), &err);
     if (err) {
         qCDebug(KLEOPATRA_LOG) << "update check failed: " << Formatting::errorAsString(err);
         return;
@@ -148,9 +136,7 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
     const auto result = results[0];
 
     if (result.update()) {
-        const QString newVersion = QStringLiteral("%1.%2.%3").arg(result.version().major)
-                                                             .arg(result.version().minor)
-                                                             .arg(result.version().patch);
+        const QString newVersion = QStringLiteral("%1.%2.%3").arg(result.version().major).arg(result.version().minor).arg(result.version().patch);
         qCDebug(KLEOPATRA_LOG) << "Have update to version:" << newVersion;
         UpdateNotification notifier(parent, newVersion);
         notifier.exec();
@@ -159,10 +145,7 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
     } else {
         qCDebug(KLEOPATRA_LOG) << "No update for:" << current;
         if (force) {
-            KMessageBox::information(parent,
-                                     i18nc("@info",
-                                           "No update found in the available version database."),
-                                     i18nc("@title", "Up to date"));
+            KMessageBox::information(parent, i18nc("@info", "No update found in the available version database."), i18nc("@title", "Up to date"));
         }
     }
 #else
@@ -171,9 +154,8 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
 #endif
 }
 
-
-UpdateNotification::UpdateNotification(QWidget *parent, const QString &version) :
-    QDialog(parent)
+UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
+    : QDialog(parent)
 {
     resize(400, 200);
     auto lay = new QGridLayout(this);
@@ -183,16 +165,13 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
     setAttribute(Qt::WA_QuitOnClose, false);
 
     KIconLoader *const il = KIconLoader::global();
-    const QString iconPath = il->iconPath(QStringLiteral("gpg4win"),
-                                          KIconLoader::User);
+    const QString iconPath = il->iconPath(QStringLiteral("gpg4win"), KIconLoader::User);
     logo->setPixmap(QIcon(iconPath).pixmap(100, 100));
 
     auto label = new HtmlLabel;
     const QString boldVersion = QStringLiteral("<b>%1</b>").arg(version);
-    label->setHtml(i18nc("%1 is the version number", "Version %1 is available.", boldVersion) +
-        QStringLiteral("<br><br>") +
-        i18nc("Link to NEWS style changelog",
-              "See the <a href=\"https://www.gpg4win.org/change-history.html\">new features</a>."));
+    label->setHtml(i18nc("%1 is the version number", "Version %1 is available.", boldVersion) + QStringLiteral("<br><br>")
+                   + i18nc("Link to NEWS style changelog", "See the <a href=\"https://www.gpg4win.org/change-history.html\">new features</a>."));
     label->setOpenExternalLinks(true);
     label->setTextInteractionFlags(Qt::TextBrowserInteraction);
     label->setWordWrap(true);
@@ -201,10 +180,10 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
 
     lay->addWidget(logo, 0, 0);
     lay->addWidget(label, 0, 1);
-    const auto chk = new QCheckBox (i18n("Show this notification for future updates."));
+    const auto chk = new QCheckBox(i18n("Show this notification for future updates."));
     lay->addWidget(chk, 1, 0, 1, -1);
 
-    KConfigGroup updatecfg(KSharedConfig::openConfig(), "UpdateNotification");
+    KConfigGroup updatecfg(KSharedConfig::openConfig(), QStringLiteral("UpdateNotification"));
     chk->setChecked(!updatecfg.readEntry("NeverShow", false));
 
     const auto bb = new QDialogButtonBox();
@@ -213,17 +192,17 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
     b->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
     bb->addButton(QDialogButtonBox::Cancel);
     lay->addWidget(bb, 2, 0, 1, -1);
-    connect (bb, &QDialogButtonBox::accepted, this, [this, chk]() {
-            QDesktopServices::openUrl(QUrl(QStringLiteral("https://www.gpg4win.org/download.html")));
-            KConfigGroup updatecfg(KSharedConfig::openConfig(), "UpdateNotification");
-            updatecfg.writeEntry("NeverShow", !chk->isChecked());
-            gpgconf_set_update_check (chk->isChecked());
-            QDialog::accept();
-        });
-    connect (bb, &QDialogButtonBox::rejected, this, [this, chk]() {
-            KConfigGroup updatecfg(KSharedConfig::openConfig(), "UpdateNotification");
-            updatecfg.writeEntry("NeverShow", !chk->isChecked());
-            gpgconf_set_update_check (chk->isChecked());
-            QDialog::reject();
-        });
+    connect(bb, &QDialogButtonBox::accepted, this, [this, chk]() {
+        QDesktopServices::openUrl(QUrl(QStringLiteral("https://www.gpg4win.org/download.html")));
+        KConfigGroup updatecfg(KSharedConfig::openConfig(), QStringLiteral("UpdateNotification"));
+        updatecfg.writeEntry("NeverShow", !chk->isChecked());
+        gpgconf_set_update_check(chk->isChecked());
+        QDialog::accept();
+    });
+    connect(bb, &QDialogButtonBox::rejected, this, [this, chk]() {
+        KConfigGroup updatecfg(KSharedConfig::openConfig(), QStringLiteral("UpdateNotification"));
+        updatecfg.writeEntry("NeverShow", !chk->isChecked());
+        gpgconf_set_update_check(chk->isChecked());
+        QDialog::reject();
+    });
 }
