@@ -14,14 +14,14 @@
 
 #include "kleopatraapplication.h"
 
-#include "mainwindow.h"
 #include "kleopatra_options.h"
-#include "systrayicon.h"
+#include "mainwindow.h"
 #include "settings.h"
 #include "smimevalidationpreferences.h"
+#include "systrayicon.h"
 
-#include <smartcard/readerstatus.h>
 #include <conf/configuredialog.h>
+#include <smartcard/readerstatus.h>
 
 #include <Libkleo/GnuPG>
 #include <utils/kdpipeiodevice.h>
@@ -29,36 +29,38 @@
 
 #include <gpgme++/key.h>
 
+#include <Libkleo/Classify>
 #include <Libkleo/Dn>
 #include <Libkleo/FileSystemWatcher>
 #include <Libkleo/KeyCache>
 #include <Libkleo/KeyFilterManager>
 #include <Libkleo/KeyGroupConfig>
-#include <Libkleo/Classify>
 #include <Libkleo/SystemInfo>
 
 #include <uiserver/uiserver.h>
 
-#include "commands/signencryptfilescommand.h"
-#include "commands/decryptverifyfilescommand.h"
-#include "commands/lookupcertificatescommand.h"
 #include "commands/checksumcreatefilescommand.h"
 #include "commands/checksumverifyfilescommand.h"
+#include "commands/decryptverifyfilescommand.h"
 #include "commands/detailscommand.h"
+#include "commands/importcertificatefromfilecommand.h"
+#include "commands/lookupcertificatescommand.h"
 #include "commands/newcertificatesigningrequestcommand.h"
 #include "commands/newopenpgpcertificatecommand.h"
+#include "commands/signencryptfilescommand.h"
 
 #include "dialogs/updatenotification.h"
 
+#include "kleopatra_debug.h"
+#include <KColorSchemeManager>
 #include <KIconLoader>
 #include <KLocalizedString>
-#include "kleopatra_debug.h"
 #include <KMessageBox>
 #include <KWindowSystem>
 
 #include <QDesktopServices>
-#include <QFile>
 #include <QDir>
+#include <QFile>
 #include <QFocusFrame>
 #if QT_CONFIG(graphicseffect)
 #include <QGraphicsEffect>
@@ -67,9 +69,8 @@
 #include <QStyleOption>
 #include <QStylePainter>
 
-#include <memory>
 #include <KSharedConfig>
-
+#include <memory>
 
 #ifdef Q_OS_WIN
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
@@ -142,7 +143,7 @@ void FocusFrame::paintEvent(QPaintEvent *)
     initStyleOption(&option);
     const int vmargin = style()->pixelMetric(QStyle::PM_FocusFrameVMargin, &option);
     const int hmargin = style()->pixelMetric(QStyle::PM_FocusFrameHMargin, &option);
-    const QRect rect = clipRect(widget()).adjusted(0, 0, hmargin*2, vmargin*2);
+    const QRect rect = clipRect(widget()).adjusted(0, 0, hmargin * 2, vmargin * 2);
     p.setClipRect(rect);
     p.drawPrimitive(QStyle::PE_FrameFocusRect, option);
 }
@@ -152,6 +153,7 @@ class KleopatraApplication::Private
 {
     friend class ::KleopatraApplication;
     KleopatraApplication *const q;
+
 public:
     explicit Private(KleopatraApplication *qq)
         : q(qq)
@@ -161,7 +163,8 @@ public:
         , groupConfig{std::make_shared<KeyGroupConfig>(QStringLiteral("kleopatragroupsrc"))}
     {
     }
-    ~Private() {
+    ~Private()
+    {
 #ifndef QT_NO_SYSTEMTRAYICON
         delete sysTray;
 #endif
@@ -174,10 +177,8 @@ public:
         sysTray->setFirstCardWithNullPin(readerStatus->firstCardWithNullPin());
         sysTray->setAnyCardCanLearnKeys(readerStatus->anyCardCanLearnKeys());
 
-        connect(readerStatus.get(), &SmartCard::ReaderStatus::firstCardWithNullPinChanged,
-                sysTray, &SysTrayIcon::setFirstCardWithNullPin);
-        connect(readerStatus.get(), &SmartCard::ReaderStatus::anyCardCanLearnKeysChanged,
-                sysTray, &SysTrayIcon::setAnyCardCanLearnKeys);
+        connect(readerStatus.get(), &SmartCard::ReaderStatus::firstCardWithNullPinChanged, sysTray, &SysTrayIcon::setFirstCardWithNullPin);
+        connect(readerStatus.get(), &SmartCard::ReaderStatus::anyCardCanLearnKeysChanged, sysTray, &SysTrayIcon::setAnyCardCanLearnKeys);
 #endif
     }
 
@@ -186,22 +187,18 @@ private:
     {
         if (configureDialog) {
             if (q->mainWindow()) {
-                connect(configureDialog, SIGNAL(configCommitted()),
-                        q->mainWindow(), SLOT(slotConfigCommitted()));
+                connect(configureDialog, SIGNAL(configCommitted()), q->mainWindow(), SLOT(slotConfigCommitted()));
             }
-            connect(configureDialog, &ConfigureDialog::configCommitted,
-                    q, &KleopatraApplication::configurationChanged);
+            connect(configureDialog, &ConfigureDialog::configCommitted, q, &KleopatraApplication::configurationChanged);
         }
     }
     void disconnectConfigureDialog()
     {
         if (configureDialog) {
             if (q->mainWindow()) {
-                disconnect(configureDialog, SIGNAL(configCommitted()),
-                           q->mainWindow(), SLOT(slotConfigCommitted()));
+                disconnect(configureDialog, SIGNAL(configCommitted()), q->mainWindow(), SLOT(slotConfigCommitted()));
             }
-            disconnect(configureDialog, &ConfigureDialog::configCommitted,
-                       q, &KleopatraApplication::configurationChanged);
+            disconnect(configureDialog, &ConfigureDialog::configCommitted, q, &KleopatraApplication::configurationChanged);
         }
     }
 
@@ -233,6 +230,10 @@ public:
         keyCache->addFileSystemWatcher(watcher);
         keyCache->setGroupConfig(groupConfig);
         keyCache->setGroupsEnabled(Settings().groupsEnabled());
+        // always enable remarks (aka tags); in particular, this triggers a
+        // relisting of the keys with signatures and signature notations
+        // after the initial (fast) key listing
+        keyCache->enableRemarks(true);
     }
 
     void setUpFilterManager()
@@ -288,23 +289,22 @@ public:
 };
 
 KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
-    : QApplication(argc, argv), d(new Private(this))
+    : QApplication(argc, argv)
+    , d(new Private(this))
 {
     // disable parent<->child navigation in tree views with left/right arrow keys
     // because this interferes with column by column navigation that is required
     // for accessibility
     setStyleSheet(QStringLiteral("QTreeView { arrow-keys-navigate-into-children: 0; }"));
-    connect(this, &QApplication::focusChanged,
-            this, [this](QWidget *, QWidget *now) {
-                d->updateFocusFrame(now);
-            });
+    connect(this, &QApplication::focusChanged, this, [this](QWidget *, QWidget *now) {
+        d->updateFocusFrame(now);
+    });
 }
 
 void KleopatraApplication::init()
 {
 #ifdef Q_OS_WIN
-    QWindowsWindowFunctions::setWindowActivationBehavior(
-            QWindowsWindowFunctions::AlwaysActivateWindow);
+    QWindowsWindowFunctions::setWindowActivationBehavior(QWindowsWindowFunctions::AlwaysActivateWindow);
 #endif
     const auto blockedUrlSchemes = Settings{}.blockedUrlSchemes();
     for (const auto &scheme : blockedUrlSchemes) {
@@ -320,33 +320,34 @@ void KleopatraApplication::init()
      * is killed while Kleopatra is running. */
     startGpgAgent();
     d->readerStatus.reset(new SmartCard::ReaderStatus);
-    connect(d->readerStatus.get(), &SmartCard::ReaderStatus::startOfGpgAgentRequested,
-            this, &KleopatraApplication::startGpgAgent);
+    connect(d->readerStatus.get(), &SmartCard::ReaderStatus::startOfGpgAgentRequested, this, &KleopatraApplication::startGpgAgent);
     d->setupKeyCache();
     d->setUpSysTrayIcon();
     d->setUpFilterManager();
     d->setupLogging();
 #ifdef Q_OS_WIN
-    // Under Linux the Theme is set outside. On Windows we have to do
-    // it ourself.
-    if (SystemInfo::isDarkModeActive()) {
-        QIcon::setThemeName("breeze-dark");
+    if (!SystemInfo::isHighContrastModeActive()) {
+        /* In high contrast mode we do not want our own colors */
+        new KColorSchemeManager(this);
     }
+#else
+    new KColorSchemeManager(this);
 #endif
+
 #ifndef QT_NO_SYSTEMTRAYICON
     d->sysTray->show();
 #endif
     setQuitOnLastWindowClosed(false);
+
+    // Sync config when we are about to quit
+    connect(this, &QApplication::aboutToQuit, this, []() {
+        KSharedConfig::openConfig()->sync();
+    });
 }
 
 KleopatraApplication::~KleopatraApplication()
 {
-    // main window doesn't receive "close" signal and cannot
-    // save settings before app exit
     delete d->mainWindow;
-
-    // work around kdelibs bug https://bugs.kde.org/show_bug.cgi?id=162514
-    KSharedConfig::openConfig()->sync();
 }
 
 namespace
@@ -354,8 +355,7 @@ namespace
 using Func = void (KleopatraApplication::*)(const QStringList &, GpgME::Protocol);
 }
 
-void KleopatraApplication::slotActivateRequested(const QStringList &arguments,
-        const QString &workingDirectory)
+void KleopatraApplication::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
 {
     QCommandLineParser parser;
 
@@ -382,8 +382,7 @@ void KleopatraApplication::slotActivateRequested(const QStringList &arguments,
     Q_EMIT setExitValue(0);
 }
 
-QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
-        const QString &workingDirectory)
+QString KleopatraApplication::newInstance(const QCommandLineParser &parser, const QString &workingDirectory)
 {
     if (d->ignoreNewInstance) {
         qCDebug(KLEOPATRA_LOG) << "New instance ignored because of ignoreNewInstance";
@@ -500,16 +499,21 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
         QString optionName;
         Func func;
     };
-    static const std::vector<FuncInfo> funcMap {
-        { QStringLiteral("import-certificate"), &KleopatraApplication::importCertificatesFromFile },
-        { QStringLiteral("encrypt"), &KleopatraApplication::encryptFiles },
-        { QStringLiteral("sign"), &KleopatraApplication::signFiles },
-        { QStringLiteral("encrypt-sign"), &KleopatraApplication::signEncryptFiles },
-        { QStringLiteral("sign-encrypt"), &KleopatraApplication::signEncryptFiles },
-        { QStringLiteral("decrypt"), &KleopatraApplication::decryptFiles },
-        { QStringLiteral("verify"), &KleopatraApplication::verifyFiles },
-        { QStringLiteral("decrypt-verify"), &KleopatraApplication::decryptVerifyFiles },
-        { QStringLiteral("checksum"), &KleopatraApplication::checksumFiles },
+
+    // While most of these options can be handled by the content autodetection
+    // below it might be useful to override the autodetection if the input is in
+    // doubt and you e.g. only want to import .asc files or fail and not decrypt them
+    // if they are actually encrypted data.
+    static const std::vector<FuncInfo> funcMap{
+        {QStringLiteral("import-certificate"), &KleopatraApplication::importCertificatesFromFile},
+        {QStringLiteral("encrypt"), &KleopatraApplication::encryptFiles},
+        {QStringLiteral("sign"), &KleopatraApplication::signFiles},
+        {QStringLiteral("encrypt-sign"), &KleopatraApplication::signEncryptFiles},
+        {QStringLiteral("sign-encrypt"), &KleopatraApplication::signEncryptFiles},
+        {QStringLiteral("decrypt"), &KleopatraApplication::decryptFiles},
+        {QStringLiteral("verify"), &KleopatraApplication::verifyFiles},
+        {QStringLiteral("decrypt-verify"), &KleopatraApplication::decryptVerifyFiles},
+        {QStringLiteral("checksum"), &KleopatraApplication::checksumFiles},
     };
 
     QString found;
@@ -537,13 +541,13 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
                 openOrRaiseMainWindow();
             }
         } else {
-            for (const QString& fileName : std::as_const(files)) {
+            for (const QString &fileName : std::as_const(files)) {
                 QFileInfo fi(fileName);
                 if (!fi.isReadable()) {
                     errors << i18n("Cannot read \"%1\"", fileName);
                 }
             }
-            const QVector<Command *> allCmds = Command::commandsForFiles(files);
+            const QList<Command *> allCmds = Command::commandsForFiles(files);
             for (Command *cmd : allCmds) {
                 if (parentId) {
                     cmd->setParentWId(parentId);
@@ -557,6 +561,9 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
                     }
                     cmd->setParentWidget(mw);
                 }
+                if (dynamic_cast<ImportCertificateFromFileCommand *>(cmd)) {
+                    openOrRaiseMainWindow();
+                }
                 cmd->start();
             }
         }
@@ -668,7 +675,6 @@ void KleopatraApplication::restoreMainWindow()
     mw->setAttribute(Qt::WA_DeleteOnClose);
     setMainWindow(mw);
     d->connectConfigureDialog();
-
 }
 
 void KleopatraApplication::openOrRaiseMainWindow()
@@ -817,8 +823,7 @@ bool KleopatraApplication::ignoreNewInstance() const
 void KleopatraApplication::blockUrl(const QUrl &url)
 {
     qCDebug(KLEOPATRA_LOG) << "Blocking URL" << url;
-    KMessageBox::error(mainWindow(),i18n ("Opening an external link is administratively prohibited."),
-                i18n ("Prohibited"));
+    KMessageBox::error(mainWindow(), i18n("Opening an external link is administratively prohibited."), i18n("Prohibited"));
 }
 
 void KleopatraApplication::startGpgAgent()
@@ -827,3 +832,5 @@ void KleopatraApplication::startGpgAgent()
 }
 
 #include "kleopatraapplication.moc"
+
+#include "moc_kleopatraapplication.cpp"
