@@ -10,27 +10,28 @@
 #include <config-kleopatra.h>
 
 #include "kwatchgnupgconfig.h"
+
 #include "kwatchgnupg.h"
 
 #include "utils/qt-cxx20-compat.h"
 
 #include <Libkleo/FileNameRequester>
 
-#include <KLocalizedString>
 #include <KConfig>
+#include <KLocalizedString>
 #include <KPluralHandlingSpinBox>
 
-#include <QVBoxLayout>
-#include <QLabel>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <QCheckBox>
 #include <QComboBox>
-#include <QPushButton>
-#include <QGroupBox>
-#include <KSharedConfig>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
+#include <QGroupBox>
+#include <QLabel>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-static const char *log_levels[] = { "none", "basic", "advanced", "expert", "guru" };
+static const char *log_levels[] = {"none", "basic", "advanced", "expert", "guru"};
 
 static int log_level_to_int(const QString &loglevel)
 {
@@ -107,7 +108,7 @@ KWatchGnuPGConfig::KWatchGnuPGConfig(QWidget *parent)
     glay->addWidget(label, row, 0);
     glay->addWidget(mLogLevelCB, row, 1);
 
-    connect(mLogLevelCB, qOverload<int>(&QComboBox::activated), this, &KWatchGnuPGConfig::slotChanged);
+    connect(mLogLevelCB, &QComboBox::activated, this, &KWatchGnuPGConfig::slotChanged);
 
     /******************* Log Window group *******************/
     group = new QGroupBox(i18n("Log Window"), top);
@@ -131,11 +132,7 @@ KWatchGnuPGConfig::KWatchGnuPGConfig(QWidget *parent)
     auto button = new QPushButton(i18n("Set &Unlimited"), group);
     glay->addWidget(button, row, 2);
 
-#if QT_DEPRECATED_SINCE(5, 14)
-    connect(mLoglenSB, qOverload<int>(&QSpinBox::valueChanged), this, &KWatchGnuPGConfig::slotChanged);
-#else
     connect(mLoglenSB, &QSpinBox::valueChanged, this, &KWatchGnuPGConfig::slotChanged);
-#endif
     connect(button, &QPushButton::clicked, this, &KWatchGnuPGConfig::slotSetHistorySizeUnlimited);
 
     ++row;
@@ -150,7 +147,9 @@ KWatchGnuPGConfig::KWatchGnuPGConfig(QWidget *parent)
     connect(okButton, &QPushButton::clicked, this, &KWatchGnuPGConfig::slotSave);
 }
 
-KWatchGnuPGConfig::~KWatchGnuPGConfig() {}
+KWatchGnuPGConfig::~KWatchGnuPGConfig()
+{
+}
 
 void KWatchGnuPGConfig::slotSetHistorySizeUnlimited()
 {
@@ -159,12 +158,12 @@ void KWatchGnuPGConfig::slotSetHistorySizeUnlimited()
 
 void KWatchGnuPGConfig::loadConfig()
 {
-    const KConfigGroup watchGnuPG(KSharedConfig::openConfig(), "WatchGnuPG");
+    const KConfigGroup watchGnuPG(KSharedConfig::openConfig(), QStringLiteral("WatchGnuPG"));
     mExeED->setFileName(watchGnuPG.readEntry("Executable", WATCHGNUPGBINARY));
     mSocketED->setFileName(watchGnuPG.readEntry("Socket", WATCHGNUPGSOCKET));
     mLogLevelCB->setCurrentIndex(log_level_to_int(watchGnuPG.readEntry("LogLevel", "basic")));
 
-    const KConfigGroup logWindow(KSharedConfig::openConfig(), "LogWindow");
+    const KConfigGroup logWindow(KSharedConfig::openConfig(), QStringLiteral("LogWindow"));
     mLoglenSB->setValue(logWindow.readEntry("MaxLogLen", 10000));
     mWordWrapCB->setChecked(logWindow.readEntry("WordWrap", false));
 
@@ -173,12 +172,12 @@ void KWatchGnuPGConfig::loadConfig()
 
 void KWatchGnuPGConfig::saveConfig()
 {
-    KConfigGroup watchGnuPG(KSharedConfig::openConfig(), "WatchGnuPG");
+    KConfigGroup watchGnuPG(KSharedConfig::openConfig(), QStringLiteral("WatchGnuPG"));
     watchGnuPG.writeEntry("Executable", mExeED->fileName());
     watchGnuPG.writeEntry("Socket", mSocketED->fileName());
     watchGnuPG.writeEntry("LogLevel", log_levels[mLogLevelCB->currentIndex()]);
 
-    KConfigGroup logWindow(KSharedConfig::openConfig(), "LogWindow");
+    KConfigGroup logWindow(KSharedConfig::openConfig(), QStringLiteral("LogWindow"));
     logWindow.writeEntry("MaxLogLen", mLoglenSB->value());
     logWindow.writeEntry("WordWrap", mWordWrapCB->isChecked());
 
@@ -199,3 +198,4 @@ void KWatchGnuPGConfig::slotSave()
     accept();
 }
 
+#include "moc_kwatchgnupgconfig.cpp"
