@@ -9,8 +9,8 @@
 
 #pragma once
 
-#include <kxmlguiwindow.h>
 #include <QProcess>
+#include <kxmlguiwindow.h>
 
 class KWatchGnuPGTray;
 class KWatchGnuPGConfig;
@@ -22,7 +22,7 @@ class KWatchGnuPGMainWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit KWatchGnuPGMainWindow(QWidget *parent = nullptr);
-    ~KWatchGnuPGMainWindow();
+    ~KWatchGnuPGMainWindow() override;
 
 private Q_SLOTS:
     void slotWatcherExited(int, QProcess::ExitStatus);
@@ -54,5 +54,3 @@ private:
     KWatchGnuPGTray *mSysTray;
     KWatchGnuPGConfig *mConfig;
 };
-
-
