@@ -17,8 +17,8 @@
 #include "keyalgo_p.h"
 #include "listwidget.h"
 
+#include "utils/expiration.h"
 #include "utils/gui-helper.h"
-#include "utils/keys.h"
 #include "utils/scrollarea.h"
 
 #include <settings.h>
@@ -29,6 +29,7 @@
 
 #include <KDateComboBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QGpgME/CryptoConfig>
 #include <QGpgME/Protocol>
@@ -65,13 +66,13 @@ static const char CMS_KEY_TYPE_ENTRY[] = "CMSKeyType";
 // for GnuPG 2.1. The whole subkey / usage generation needs
 // new api and a reworked dialog. (ah 10.3.16)
 // EDDSA should be supported, too.
-static const QStringList curveNames {
-    { QStringLiteral("brainpoolP256r1") },
-    { QStringLiteral("brainpoolP384r1") },
-    { QStringLiteral("brainpoolP512r1") },
-    { QStringLiteral("NIST P-256") },
-    { QStringLiteral("NIST P-384") },
-    { QStringLiteral("NIST P-521") },
+static const QStringList curveNames{
+    {QStringLiteral("brainpoolP256r1")},
+    {QStringLiteral("brainpoolP384r1")},
+    {QStringLiteral("brainpoolP512r1")},
+    {QStringLiteral("NIST P-256")},
+    {QStringLiteral("NIST P-384")},
+    {QStringLiteral("NIST P-521")},
 };
 
 namespace
@@ -148,11 +149,7 @@ static void parseAlgoString(const QString &algoString, int *size, Subkey::Pubkey
 
     if (*algo != Subkey::AlgoUnknown) {
         bool ok;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        *size = lowered.rightRef(lowered.size() - 3).toInt(&ok);
-#else
         *size = QStringView(lowered).right(lowered.size() - 3).toInt(&ok);
-#endif
         if (!ok) {
             qCWarning(KLEOPATRA_LOG) << "Could not extract size from: " << lowered;
             *size = 3072;
@@ -174,10 +171,10 @@ static void parseAlgoString(const QString &algoString, int *size, Subkey::Pubkey
         return;
     }
 
-    if (lowered.startsWith(QLatin1String("cv25519")) ||
-        lowered.startsWith(QLatin1String("nist")) ||
-        lowered.startsWith(QLatin1String("brainpool")) ||
-        lowered.startsWith(QLatin1String("secp"))) {
+    if (lowered.startsWith(QLatin1String("cv25519")) //
+        || lowered.startsWith(QLatin1String("nist")) //
+        || lowered.startsWith(QLatin1String("brainpool")) //
+        || lowered.startsWith(QLatin1String("secp"))) {
         curve = split[0];
         *algo = isEncrypt ? Subkey::AlgoECDH : Subkey::AlgoECDSA;
         return;
@@ -188,8 +185,7 @@ static void parseAlgoString(const QString &algoString, int *size, Subkey::Pubkey
 
 }
 
-struct AdvancedSettingsDialog::UI
-{
+struct AdvancedSettingsDialog::UI {
     QTabWidget *tabWidget = nullptr;
     QRadioButton *rsaRB = nullptr;
     QComboBox *rsaKeyStrengthCB = nullptr;
@@ -394,7 +390,7 @@ struct AdvancedSettingsDialog::UI
         mainLayout->addWidget(tabWidget);
 
         buttonBox = new QDialogButtonBox{parent};
-        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
+        buttonBox->setStandardButtons(QDialogButtonBox::Cancel | QDialogButtonBox::Ok);
 
         mainLayout->addWidget(buttonBox);
     }
@@ -408,28 +404,13 @@ AdvancedSettingsDialog::AdvancedSettingsDialog(QWidget *parent)
 {
     qRegisterMetaType<Subkey::PubkeyAlgo>("Subkey::PubkeyAlgo");
 
-    const auto settings = Kleo::Settings{};
-    {
-        const auto minimumExpiry = std::max(0, settings.validityPeriodInDaysMin());
-        ui->expiryDE->setMinimumDate(QDate::currentDate().addDays(minimumExpiry));
-    }
-    {
-        const auto maximumExpiry = settings.validityPeriodInDaysMax();
-        if (maximumExpiry >= 0) {
-            ui->expiryDE->setMaximumDate(std::max(ui->expiryDE->minimumDate(), QDate::currentDate().addDays(maximumExpiry)));
-        }
-    }
+    Kleo::setUpExpirationDateComboBox(ui->expiryDE);
     if (unlimitedValidityIsAllowed()) {
         ui->expiryDE->setEnabled(ui->expiryCB->isChecked());
     } else {
         ui->expiryCB->setEnabled(false);
         ui->expiryCB->setChecked(true);
-        if (ui->expiryDE->maximumDate() == ui->expiryDE->minimumDate()) {
-            // validity period is a fixed number of days
-            ui->expiryDE->setEnabled(false);
-        }
     }
-    ui->expiryDE->setToolTip(validityPeriodHint(ui->expiryDE->minimumDate(), ui->expiryDE->maximumDate()));
     ui->emailLW->setDefaultValue(i18n("new email"));
     ui->dnsLW->setDefaultValue(i18n("new dns name"));
     ui->uriLW->setDefaultValue(i18n("new uri"));
@@ -454,56 +435,22 @@ AdvancedSettingsDialog::AdvancedSettingsDialog(QWidget *parent)
     connect(ui->signingCB, &QAbstractButton::toggled, this, &AdvancedSettingsDialog::slotSigningAllowedToggled);
     connect(ui->encryptionCB, &QAbstractButton::toggled, this, &AdvancedSettingsDialog::slotEncryptionAllowedToggled);
 
-    connect(ui->expiryCB, &QAbstractButton::toggled,
-            this, [this](bool checked) {
-                ui->expiryDE->setEnabled(checked);
-                if (checked && !ui->expiryDE->isValid()) {
-                    setExpiryDate(defaultExpirationDate(ExpirationOnUnlimitedValidity::InternalDefaultExpiration));
-                }
-            });
+    connect(ui->expiryCB, &QAbstractButton::toggled, this, [this](bool checked) {
+        ui->expiryDE->setEnabled(checked);
+        if (checked && !ui->expiryDE->isValid()) {
+            setExpiryDate(defaultExpirationDate(ExpirationOnUnlimitedValidity::InternalDefaultExpiration));
+        }
+    });
 
-    connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &AdvancedSettingsDialog::accept);
     connect(ui->buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 AdvancedSettingsDialog::~AdvancedSettingsDialog() = default;
 
-QString AdvancedSettingsDialog::dateToString(const QDate &date) const
-{
-    // workaround for QLocale using "yy" way too often for years
-    // stolen from KDateComboBox
-    const auto dateFormat = (locale().dateFormat(QLocale::ShortFormat) //
-                                    .replace(QLatin1String{"yy"}, QLatin1String{"yyyy"})
-                                    .replace(QLatin1String{"yyyyyyyy"}, QLatin1String{"yyyy"}));
-    return locale().toString(date, dateFormat);
-}
-
-QString AdvancedSettingsDialog::validityPeriodHint(const QDate &minDate, const QDate &maxDate) const
-{
-    // Note: minDate is always valid
-    const auto today = QDate::currentDate();
-    if (maxDate.isValid()) {
-        if (maxDate == minDate) {
-            return i18n("The validity period cannot be changed.");
-        } else if (minDate == today) {
-            return i18nc("... between today and <another date>.", "The validity period must end between today and %1.",
-                            dateToString(maxDate));
-        } else {
-            return i18nc("... between <a date> and <another date>.", "The validity period must end between %1 and %2.",
-                            dateToString(minDate), dateToString(maxDate));
-        }
-    } else {
-        if (minDate == today) {
-            return i18n("The validity period must end after today.");
-        } else {
-            return i18nc("... after <a date>.", "The validity period must end after %1.", dateToString(minDate));
-        }
-    }
-}
-
 bool AdvancedSettingsDialog::unlimitedValidityIsAllowed() const
 {
-    return !ui->expiryDE->maximumDate().isValid();
+    return !Kleo::maximumExpirationDate().isValid();
 }
 
 void AdvancedSettingsDialog::setProtocol(GpgME::Protocol proto)
@@ -563,17 +510,12 @@ void AdvancedSettingsDialog::setKeyStrength(unsigned int strength)
 
 unsigned int AdvancedSettingsDialog::keyStrength() const
 {
-    return
-        ui->dsaRB->isChecked() ? get_keysize(ui->dsaKeyStrengthCB) :
-        ui->rsaRB->isChecked() ? get_keysize(ui->rsaKeyStrengthCB) : 0;
+    return ui->dsaRB->isChecked() ? get_keysize(ui->dsaKeyStrengthCB) : ui->rsaRB->isChecked() ? get_keysize(ui->rsaKeyStrengthCB) : 0;
 }
 
 void AdvancedSettingsDialog::setKeyType(Subkey::PubkeyAlgo algo)
 {
-    QRadioButton *const rb =
-        is_rsa(algo) ? ui->rsaRB :
-        is_dsa(algo) ? ui->dsaRB :
-        is_ecdsa(algo) || is_eddsa(algo) ? ui->ecdsaRB : nullptr;
+    QRadioButton *const rb = is_rsa(algo) ? ui->rsaRB : is_dsa(algo) ? ui->dsaRB : is_ecdsa(algo) || is_eddsa(algo) ? ui->ecdsaRB : nullptr;
     if (rb) {
         rb->setChecked(true);
     }
@@ -581,13 +523,10 @@ void AdvancedSettingsDialog::setKeyType(Subkey::PubkeyAlgo algo)
 
 Subkey::PubkeyAlgo AdvancedSettingsDialog::keyType() const
 {
-    return
-        ui->dsaRB->isChecked() ? Subkey::AlgoDSA :
-        ui->rsaRB->isChecked() ? Subkey::AlgoRSA :
-        ui->ecdsaRB->isChecked() ?
-            ui->ecdsaKeyCurvesCB->currentText() == QLatin1String("ed25519") ? Subkey::AlgoEDDSA :
-            Subkey::AlgoECDSA :
-        Subkey::AlgoUnknown;
+    return ui->dsaRB->isChecked()  ? Subkey::AlgoDSA
+        : ui->rsaRB->isChecked()   ? Subkey::AlgoRSA
+        : ui->ecdsaRB->isChecked() ? ui->ecdsaKeyCurvesCB->currentText() == QLatin1String("ed25519") ? Subkey::AlgoEDDSA : Subkey::AlgoECDSA
+                                   : Subkey::AlgoUnknown;
 }
 
 void AdvancedSettingsDialog::setKeyCurve(const QString &curve)
@@ -713,9 +652,10 @@ void AdvancedSettingsDialog::setExpiryDate(QDate date)
         ui->expiryCB->setChecked(ui->expiryDE->isValid());
     }
 }
+
 QDate AdvancedSettingsDialog::expiryDate() const
 {
-    return ui->expiryCB->isChecked() ? forceDateIntoAllowedRange(ui->expiryDE->date()) : QDate();
+    return ui->expiryCB->isChecked() ? ui->expiryDE->date() : QDate{};
 }
 
 void AdvancedSettingsDialog::slotKeyMaterialSelectionChanged()
@@ -769,7 +709,7 @@ void AdvancedSettingsDialog::slotKeyMaterialSelectionChanged()
             ui->encryptionCB->setChecked(is_ecdh(sk_algo));
         }
     } else {
-        //assert( is_rsa( keyType() ) ); // it can happen through misconfiguration by the admin that no key type is selectable at all
+        // assert( is_rsa( keyType() ) ); // it can happen through misconfiguration by the admin that no key type is selectable at all
     }
 }
 
@@ -796,8 +736,8 @@ static void fill_combobox(QComboBox &cb, const QList<int> &sizes, const QStringL
          * defaults in Kleopatra its difficult to print out "default" here. To avoid confusion
          * about that its better not to show any default indication.  */
         cb.addItem(i < labels.size() && !labels[i].trimmed().isEmpty()
-                   ? i18ncp("%2: some admin-supplied text, %1: key size in bits", "%2 (1 bit)", "%2 (%1 bits)", size, labels[i].trimmed())
-                   : i18ncp("%1: key size in bits", "1 bit", "%1 bits", size),
+                       ? i18ncp("%2: some admin-supplied text, %1: key size in bits", "%2 (1 bit)", "%2 (%1 bits)", size, labels[i].trimmed())
+                       : i18ncp("%1: key size in bits", "1 bit", "%1 bits", size),
                    size);
         if (sizes[i] < 0) {
             cb.setCurrentIndex(cb.count() - 1);
@@ -807,8 +747,7 @@ static void fill_combobox(QComboBox &cb, const QList<int> &sizes, const QStringL
 
 void AdvancedSettingsDialog::fillKeySizeComboBoxen()
 {
-
-    const KConfigGroup config(KSharedConfig::openConfig(), "CertificateCreationWizard");
+    const KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("CertificateCreationWizard"));
 
     QList<int> rsaKeySizes = config.readEntry(RSA_KEYSIZES_ENTRY, QList<int>() << 2048 << -3072 << 4096);
     if (DeVSCompliance::isActive()) {
@@ -898,12 +837,11 @@ void AdvancedSettingsDialog::loadDefaultGnuPGKeyType()
 
 void AdvancedSettingsDialog::loadDefaultKeyType()
 {
-
     if (protocol != CMS && protocol != OpenPGP) {
         return;
     }
 
-    const KConfigGroup config(KSharedConfig::openConfig(), "CertificateCreationWizard");
+    const KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("CertificateCreationWizard"));
 
     const QString entry = protocol == CMS ? QLatin1String(CMS_KEY_TYPE_ENTRY) : QLatin1String(PGP_KEY_TYPE_ENTRY);
     const QString keyType = config.readEntry(entry).trimmed().toUpper();
@@ -918,9 +856,7 @@ void AdvancedSettingsDialog::loadDefaultKeyType()
         loadDefaultGnuPGKeyType();
     } else {
         if (!keyType.isEmpty() && keyType != QLatin1String("RSA"))
-            qCWarning(KLEOPATRA_LOG) << "invalid value \"" << qPrintable(keyType)
-                                     << "\" for entry \"[CertificateCreationWizard]"
-                                     << qPrintable(entry) << "\"";
+            qCWarning(KLEOPATRA_LOG) << "invalid value \"" << qPrintable(keyType) << "\" for entry \"[CertificateCreationWizard]" << qPrintable(entry) << "\"";
         setKeyType(Subkey::AlgoRSA);
         setSubkeyType(Subkey::AlgoRSA);
     }
@@ -952,7 +888,7 @@ void AdvancedSettingsDialog::loadDefaults()
 void AdvancedSettingsDialog::updateWidgetVisibility()
 {
     // Personal Details Page
-    if (protocol == OpenPGP) {    // ### hide until multi-uid is implemented
+    if (protocol == OpenPGP) { // ### hide until multi-uid is implemented
         if (ui->tabWidget->indexOf(ui->personalTab) != -1) {
             ui->tabWidget->removeTab(ui->tabWidget->indexOf(ui->personalTab));
         }
@@ -989,16 +925,16 @@ void AdvancedSettingsDialog::updateWidgetVisibility()
         //
         // Does anyone want to use NIST anyway?
         int i;
-        while ((i = ui->ecdsaKeyCurvesCB->findText(QStringLiteral("NIST"), Qt::MatchStartsWith)) != -1 ||
-               (i = ui->ecdsaKeyCurvesCB->findText(QStringLiteral("25519"), Qt::MatchEndsWith)) != -1) {
+        while ((i = ui->ecdsaKeyCurvesCB->findText(QStringLiteral("NIST"), Qt::MatchStartsWith)) != -1
+               || (i = ui->ecdsaKeyCurvesCB->findText(QStringLiteral("25519"), Qt::MatchEndsWith)) != -1) {
             ui->ecdsaKeyCurvesCB->removeItem(i);
         }
-        while ((i = ui->ecdhKeyCurvesCB->findText(QStringLiteral("NIST"), Qt::MatchStartsWith)) != -1 ||
-               (i = ui->ecdhKeyCurvesCB->findText(QStringLiteral("25519"), Qt::MatchEndsWith)) != -1) {
+        while ((i = ui->ecdhKeyCurvesCB->findText(QStringLiteral("NIST"), Qt::MatchStartsWith)) != -1
+               || (i = ui->ecdhKeyCurvesCB->findText(QStringLiteral("25519"), Qt::MatchEndsWith)) != -1) {
             ui->ecdhKeyCurvesCB->removeItem(i);
         }
     }
-    ui->certificationCB->setVisible(protocol == OpenPGP);   // gpgsm limitation?
+    ui->certificationCB->setVisible(protocol == OpenPGP); // gpgsm limitation?
     ui->authenticationCB->setVisible(protocol == OpenPGP);
 
     if (keyTypeImmutable) {
@@ -1059,6 +995,16 @@ void AdvancedSettingsDialog::setInitialFocus()
     ui->buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
 
+void AdvancedSettingsDialog::accept()
+{
+    if (!Kleo::isValidExpirationDate(expiryDate())) {
+        KMessageBox::error(this, i18nc("@info", "Error: %1", Kleo::validityPeriodHint()));
+        return;
+    }
+
+    QDialog::accept();
+}
+
 void AdvancedSettingsDialog::showEvent(QShowEvent *event)
 {
     if (isFirstShowEvent) {
@@ -1067,3 +1013,5 @@ void AdvancedSettingsDialog::showEvent(QShowEvent *event)
     }
     QDialog::showEvent(event);
 }
+
+#include "moc_advancedsettingsdialog_p.cpp"
