@@ -41,8 +41,8 @@
 #include <QMetaProperty>
 #include <QPushButton>
 #include <QSpacerItem>
-#include <QValidator>
 #include <QVBoxLayout>
+#include <QValidator>
 
 #include "kleopatra_debug.h"
 
@@ -52,7 +52,9 @@ using namespace GpgME;
 
 static void set_tab_order(const QList<QWidget *> &wl)
 {
-    kdtools::for_each_adjacent_pair(wl.begin(), wl.end(), &QWidget::setTabOrder);
+    kdtools::for_each_adjacent_pair(wl.begin(), wl.end(), [](QWidget *w1, QWidget *w2) {
+        QWidget::setTabOrder(w1, w2);
+    });
 }
 
 static QString pgpLabel(const QString &attr)
@@ -76,8 +78,7 @@ static QString attributeLabel(const QString &attr, bool pgp)
         if (pgp) {
             return label;
         } else
-            return i18nc("Format string for the labels in the \"Your Personal Data\" page",
-                         "%1 (%2)", label, attr);
+            return i18nc("Format string for the labels in the \"Your Personal Data\" page", "%1 (%2)", label, attr);
     else {
         return attr;
     }
@@ -88,8 +89,7 @@ static QString attributeFromKey(QString key)
     return key.remove(QLatin1Char('!'));
 }
 
-struct EnterDetailsPage::UI
-{
+struct EnterDetailsPage::UI {
     QGridLayout *gridLayout = nullptr;
     QLabel *nameLB = nullptr;
     QLineEdit *nameLE = nullptr;
@@ -209,11 +209,9 @@ EnterDetailsPage::EnterDetailsPage(QWidget *p)
     ui->errorLB->clear();
 
     connect(ui->advancedPB, &QPushButton::clicked, this, &EnterDetailsPage::slotAdvancedSettingsClicked);
-    connect(ui->resultLE, &QLineEdit::textChanged,
-            this, &QWizardPage::completeChanged);
+    connect(ui->resultLE, &QLineEdit::textChanged, this, &QWizardPage::completeChanged);
     // The email doesn't necessarily show up in ui->resultLE:
-    connect(ui->emailLE, &QLineEdit::textChanged,
-            this, &QWizardPage::completeChanged);
+    connect(ui->emailLE, &QLineEdit::textChanged, this, &QWizardPage::completeChanged);
     registerDialogPropertiesAsFields();
     registerField(QStringLiteral("dn"), ui->resultLE);
     registerField(QStringLiteral("name"), ui->nameLE);
@@ -233,7 +231,7 @@ EnterDetailsPage::EnterDetailsPage(QWidget *p)
         ui->withPassCB->setEnabled(false);
         ui->withPassCB->setChecked(true);
     } else {
-        const KConfigGroup config(KSharedConfig::openConfig(), "CertificateCreationWizard");
+        const KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("CertificateCreationWizard"));
         ui->withPassCB->setChecked(config.readEntry("WithPassphrase", false));
         ui->withPassCB->setEnabled(!config.isEntryImmutable("WithPassphrase"));
     }
@@ -255,7 +253,6 @@ void EnterDetailsPage::cleanupPage()
 
 void EnterDetailsPage::registerDialogPropertiesAsFields()
 {
-
     const QMetaObject *const mo = dialog->metaObject();
     for (unsigned int i = mo->propertyOffset(), end = i + mo->propertyCount(); i != end; ++i) {
         const QMetaProperty mp = mo->property(i);
@@ -263,13 +260,12 @@ void EnterDetailsPage::registerDialogPropertiesAsFields()
             registerField(QLatin1String(mp.name()), dialog, mp.name(), SIGNAL(accepted()));
         }
     }
-
 }
 
 void EnterDetailsPage::saveValues()
 {
     for (const Line &line : std::as_const(lineList)) {
-        savedValues[ attributeFromKey(line.attr) ] = line.edit->text().trimmed();
+        savedValues[attributeFromKey(line.attr)] = line.edit->text().trimmed();
     }
 }
 
@@ -298,7 +294,8 @@ static int row_index_of(QWidget *w, QGridLayout *l)
     return r;
 }
 
-static QLineEdit *adjust_row(QGridLayout *l, int row, const QString &label, const QString &preset, const std::shared_ptr<QValidator> &validator, bool readonly, bool required)
+static QLineEdit *
+adjust_row(QGridLayout *l, int row, const QString &label, const QString &preset, const std::shared_ptr<QValidator> &validator, bool readonly, bool required)
 {
     Q_ASSERT(l);
     Q_ASSERT(row >= 0);
@@ -308,7 +305,7 @@ static QLineEdit *adjust_row(QGridLayout *l, int row, const QString &label, cons
     Q_ASSERT(lb);
     auto le = qobject_cast<QLineEdit *>(l->itemAtPosition(row, 1)->widget());
     Q_ASSERT(le);
-    lb->setBuddy(le);   // For better accessibility
+    lb->setBuddy(le); // For better accessibility
     auto reqLB = qobject_cast<QLabel *>(l->itemAtPosition(row, 2)->widget());
     Q_ASSERT(reqLB);
 
@@ -334,9 +331,9 @@ static int add_row(QGridLayout *l, QList<QWidget *> *wl)
     Q_ASSERT(wl);
     const int row = l->rowCount();
     QWidget *w1, *w2, *w3;
-    l->addWidget(w1 = new QLabel(l->parentWidget()),    row, 0);
+    l->addWidget(w1 = new QLabel(l->parentWidget()), row, 0);
     l->addWidget(w2 = new QLineEdit(l->parentWidget()), row, 1);
-    l->addWidget(w3 = new QLabel(l->parentWidget()),    row, 2);
+    l->addWidget(w3 = new QLabel(l->parentWidget()), row, 2);
     wl->push_back(w1);
     wl->push_back(w2);
     wl->push_back(w3);
@@ -345,18 +342,18 @@ static int add_row(QGridLayout *l, QList<QWidget *> *wl)
 
 void EnterDetailsPage::updateForm()
 {
-
     clearForm();
 
     const auto settings = Kleo::Settings{};
-    const KConfigGroup config(KSharedConfig::openConfig(), "CertificateCreationWizard");
+    const KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("CertificateCreationWizard"));
 
     QStringList attrOrder = config.readEntry(pgp() ? "OpenPGPAttributeOrder" : "DNAttributeOrder", QStringList());
     if (attrOrder.empty()) {
         if (pgp()) {
             attrOrder << QStringLiteral("NAME") << QStringLiteral("EMAIL");
         } else {
-            attrOrder << QStringLiteral("CN!") << QStringLiteral("L") << QStringLiteral("OU") << QStringLiteral("O") << QStringLiteral("C") << QStringLiteral("EMAIL!");
+            attrOrder << QStringLiteral("CN!") << QStringLiteral("L") << QStringLiteral("OU") << QStringLiteral("O") << QStringLiteral("C")
+                      << QStringLiteral("EMAIL!");
         }
     }
 
@@ -375,8 +372,7 @@ void EnterDetailsPage::updateForm()
         const QString preset = savedValues.value(attr, config.readEntry(attr, QString()));
         const bool required = key.endsWith(QLatin1Char('!'));
         const bool readonly = config.isEntryImmutable(attr);
-        const QString label = config.readEntry(attr + QLatin1String("_label"),
-                                               attributeLabel(attr, pgp()));
+        const QString label = config.readEntry(attr + QLatin1String("_label"), attributeLabel(attr, pgp()));
         const QString regex = config.readEntry(attr + QLatin1String("_regex"));
         const QString placeholder = config.readEntry(attr + QLatin1String{"_placeholder"});
 
@@ -405,7 +401,7 @@ void EnterDetailsPage::updateForm()
         QLineEdit *le = adjust_row(ui->gridLayout, row, label, preset, validator, readonly, required);
         le->setPlaceholderText(placeholder);
 
-        const Line line = { key, label, regex, le, validator };
+        const Line line = {key, label, regex, le, validator};
         lines[row] = line;
 
         if (!known) {
@@ -441,7 +437,7 @@ void EnterDetailsPage::updateForm()
 QString EnterDetailsPage::cmsDN() const
 {
     DN dn;
-    for (QVector<Line>::const_iterator it = lineList.begin(), end = lineList.end(); it != end; ++it) {
+    for (QList<Line>::const_iterator it = lineList.begin(), end = lineList.end(); it != end; ++it) {
         const QString text = it->edit->text().trimmed();
         if (text.isEmpty()) {
             continue;
@@ -460,10 +456,7 @@ QString EnterDetailsPage::cmsDN() const
 
 QString EnterDetailsPage::pgpUserID() const
 {
-    return Formatting::prettyNameAndEMail(OpenPGP, QString(),
-                                          ui->nameLE->text().trimmed(),
-                                          ui->emailLE->text().trimmed(),
-                                          QString());
+    return Formatting::prettyNameAndEMail(OpenPGP, QString(), ui->nameLE->text().trimmed(), ui->emailLE->text().trimmed(), QString());
 }
 
 static bool has_intermediate_input(const QLineEdit *le)
@@ -474,7 +467,7 @@ static bool has_intermediate_input(const QLineEdit *le)
     return v && v->validate(text, pos) == QValidator::Intermediate;
 }
 
-static bool requirementsAreMet(const QVector<EnterDetailsPage::Line> &list, QString &error)
+static bool requirementsAreMet(const QList<EnterDetailsPage::Line> &list, QString &error)
 {
     bool allEmpty = true;
     for (const auto &line : list) {
@@ -489,23 +482,32 @@ static bool requirementsAreMet(const QVector<EnterDetailsPage::Line> &list, QStr
                 if (line.regex.isEmpty()) {
                     error = xi18nc("@info", "<interface>%1</interface> is required, but empty.", line.label);
                 } else
-                    error = xi18nc("@info", "<interface>%1</interface> is required, but empty.<nl/>"
-                                   "Local Admin rule: <icode>%2</icode>", line.label, line.regex);
+                    error = xi18nc("@info",
+                                   "<interface>%1</interface> is required, but empty.<nl/>"
+                                   "Local Admin rule: <icode>%2</icode>",
+                                   line.label,
+                                   line.regex);
                 return false;
             }
         } else if (has_intermediate_input(le)) {
             if (line.regex.isEmpty()) {
                 error = xi18nc("@info", "<interface>%1</interface> is incomplete.", line.label);
             } else
-                error = xi18nc("@info", "<interface>%1</interface> is incomplete.<nl/>"
-                               "Local Admin rule: <icode>%2</icode>", line.label, line.regex);
+                error = xi18nc("@info",
+                               "<interface>%1</interface> is incomplete.<nl/>"
+                               "Local Admin rule: <icode>%2</icode>",
+                               line.label,
+                               line.regex);
             return false;
         } else if (!le->hasAcceptableInput()) {
             if (line.regex.isEmpty()) {
                 error = xi18nc("@info", "<interface>%1</interface> is invalid.", line.label);
             } else
-                error = xi18nc("@info", "<interface>%1</interface> is invalid.<nl/>"
-                               "Local Admin rule: <icode>%2</icode>", line.label, line.regex);
+                error = xi18nc("@info",
+                               "<interface>%1</interface> is invalid.<nl/>"
+                               "Local Admin rule: <icode>%2</icode>",
+                               line.label,
+                               line.regex);
             return false;
         } else {
             allEmpty = false;
@@ -532,3 +534,5 @@ void EnterDetailsPage::slotUpdateResultLabel()
 {
     ui->resultLE->setText(pgp() ? pgpUserID() : cmsDN());
 }
+
+#include "moc_enterdetailspage_p.cpp"
