@@ -24,7 +24,10 @@
 
 #include "algorithminfo.h"
 
+#include <utils/qt-cxx20-compat.h>
+
 #include <Libkleo/Algorithm>
+#include <Libkleo/GnuPG>
 
 #include <KLocalizedString>
 
@@ -33,13 +36,6 @@
 using namespace Kleo;
 using namespace Kleo::SmartCard;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
-static QDebug operator<<(QDebug s, const std::string &string)
-{
-    return s << QString::fromStdString(string);
-}
-#endif
-
 // static
 const std::string OpenPGPCard::AppName = "openpgp";
 
@@ -87,12 +83,12 @@ std::string OpenPGPCard::resetCodeKeyRef()
 }
 
 // static
-const std::vector<KeyPairInfo> & OpenPGPCard::supportedKeys()
+const std::vector<KeyPairInfo> &OpenPGPCard::supportedKeys()
 {
     static const std::vector<KeyPairInfo> keyInfos = {
         {OpenPGPCard::pgpSigKeyRef(), "", "sc", "", ""},
         {OpenPGPCard::pgpEncKeyRef(), "", "e", "", ""},
-        {OpenPGPCard::pgpAuthKeyRef(), "", "a", "", ""}
+        {OpenPGPCard::pgpAuthKeyRef(), "", "a", "", ""},
     };
 
     return keyInfos;
@@ -102,9 +98,9 @@ const std::vector<KeyPairInfo> & OpenPGPCard::supportedKeys()
 QString OpenPGPCard::keyDisplayName(const std::string &keyRef)
 {
     static const QMap<std::string, QString> displayNames = {
-        { OpenPGPCard::pgpSigKeyRef(), i18n("Signature") },
-        { OpenPGPCard::pgpEncKeyRef(), i18n("Encryption") },
-        { OpenPGPCard::pgpAuthKeyRef(), i18n("Authentication") }
+        {OpenPGPCard::pgpSigKeyRef(), i18n("Signature")},
+        {OpenPGPCard::pgpEncKeyRef(), i18n("Encryption")},
+        {OpenPGPCard::pgpAuthKeyRef(), i18n("Authentication")},
     };
 
     return displayNames.value(keyRef);
@@ -114,12 +110,12 @@ QString OpenPGPCard::keyDisplayName(const std::string &keyRef)
 std::string OpenPGPCard::getAlgorithmName(const std::string &algorithm, const std::string &keyRef)
 {
     static const std::map<std::string, std::string> ecdhAlgorithmMapping = {
-        { "curve25519", "cv25519" },
-        { "curve448", "cv448" },
+        {"curve25519", "cv25519"},
+        {"curve448", "cv448"},
     };
     static const std::map<std::string, std::string> eddsaAlgorithmMapping = {
-        { "curve25519", "ed25519" },
-        { "curve448", "ed448" },
+        {"curve25519", "ed25519"},
+        {"curve448", "ed448"},
     };
     if (keyRef == OpenPGPCard::pgpEncKeyRef()) {
         const auto it = ecdhAlgorithmMapping.find(algorithm);
@@ -137,35 +133,20 @@ std::string OpenPGPCard::getAlgorithmName(const std::string &algorithm, const st
 
 void OpenPGPCard::setSupportedAlgorithms(const std::vector<std::string> &algorithms)
 {
-    static const std::vector<std::string> allowedAlgorithms = {
-        "brainpoolP256r1",
-        "brainpoolP384r1",
-        "brainpoolP512r1",
-        "curve25519",
-        "curve448",
-        "nistp256",
-        "nistp384",
-        "nistp521",
-        "rsa2048",
-        "rsa3072",
-        "rsa4096",
-    };
-    // Curve secp256k1 is explicitly ignored
-    static const std::vector<std::string> ignoredAlgorithms = {
-        "secp256k1",
-    };
+    const auto &availableAlgos = Kleo::availableAlgorithms();
+    const auto &ignoredAlgos = Kleo::ignoredAlgorithms();
     mAlgorithms.clear();
-    std::copy_if(algorithms.begin(), algorithms.end(), std::back_inserter(mAlgorithms), [](const auto &algo) {
-        return Kleo::contains(allowedAlgorithms, algo);
+    Kleo::copy_if(algorithms, std::back_inserter(mAlgorithms), [&availableAlgos](const auto &algo) {
+        return Kleo::contains(availableAlgos, algo);
     });
     if (mAlgorithms.size() < algorithms.size()) {
         std::vector<std::string> unsupportedAlgos;
-        std::copy_if(algorithms.begin(), algorithms.end(), std::back_inserter(unsupportedAlgos), [](const auto &algo) {
-            return !Kleo::contains(ignoredAlgorithms, algo) && !Kleo::contains(allowedAlgorithms, algo);
+        Kleo::copy_if(algorithms, std::back_inserter(unsupportedAlgos), [&availableAlgos, &ignoredAlgos](const auto &algo) {
+            return !Kleo::contains(ignoredAlgos, algo) && !Kleo::contains(availableAlgos, algo);
         });
         if (unsupportedAlgos.size() > 0) {
-            qWarning(KLEOPATRA_LOG).nospace() << "OpenPGPCard::" << __func__ << " Unsupported algorithms: " << unsupportedAlgos
-                                              << " (supported: " << allowedAlgorithms << ")";
+            qCWarning(KLEOPATRA_LOG).nospace() << "OpenPGPCard::" << __func__ << " Unsupported algorithms: " << unsupportedAlgos
+                                               << " (supported: " << availableAlgos << ")";
         }
     }
 }
@@ -178,17 +159,17 @@ std::string OpenPGPCard::pubkeyUrl() const
 std::vector<AlgorithmInfo> OpenPGPCard::supportedAlgorithms() const
 {
     static const std::map<std::string, QString> displayNames = {
-        { "brainpoolP256r1", i18nc("@info", "ECC (Brainpool P-256)") },
-        { "brainpoolP384r1", i18nc("@info", "ECC (Brainpool P-384)") },
-        { "brainpoolP512r1", i18nc("@info", "ECC (Brainpool P-512)") },
-        { "curve25519", i18nc("@info", "ECC (Curve25519)") },
-        { "curve448", i18nc("@info", "ECC (Curve448)") },
-        { "nistp256", i18nc("@info", "ECC (NIST P-256)") },
-        { "nistp384", i18nc("@info", "ECC (NIST P-384)") },
-        { "nistp521", i18nc("@info", "ECC (NIST P-521)") },
-        { "rsa2048", i18nc("@info", "RSA 2048") },
-        { "rsa3072", i18nc("@info", "RSA 3072") },
-        { "rsa4096", i18nc("@info", "RSA 4096") },
+        {"brainpoolP256r1", i18nc("@info", "ECC (Brainpool P-256)")},
+        {"brainpoolP384r1", i18nc("@info", "ECC (Brainpool P-384)")},
+        {"brainpoolP512r1", i18nc("@info", "ECC (Brainpool P-512)")},
+        {"curve25519", i18nc("@info", "ECC (Curve25519)")},
+        {"curve448", i18nc("@info", "ECC (Curve448)")},
+        {"nistp256", i18nc("@info", "ECC (NIST P-256)")},
+        {"nistp384", i18nc("@info", "ECC (NIST P-384)")},
+        {"nistp521", i18nc("@info", "ECC (NIST P-521)")},
+        {"rsa2048", i18nc("@info", "RSA 2048")},
+        {"rsa3072", i18nc("@info", "RSA 3072")},
+        {"rsa4096", i18nc("@info", "RSA 4096")},
     };
     std::vector<AlgorithmInfo> algos;
     std::transform(mAlgorithms.cbegin(), mAlgorithms.cend(), std::back_inserter(algos), [](const auto &algo) {
@@ -197,11 +178,7 @@ std::vector<AlgorithmInfo> OpenPGPCard::supportedAlgorithms() const
     return algos;
 }
 
-std::string OpenPGPCard::defaultAlgorithm() const
+bool OpenPGPCard::isSupportedAlgorithm(const std::string &algorithm) const
 {
-    if (Kleo::contains(mAlgorithms, "curve25519")) {
-        return "curve25519";
-    }
-    // we assume that all OpenPGP smart cards support at least RSA with 2048 bits
-    return "rsa2048";
+    return Kleo::contains(mAlgorithms, algorithm);
 }
