@@ -37,8 +37,10 @@ class KeyTreeView : public QWidget
     Q_OBJECT
 public:
     explicit KeyTreeView(QWidget *parent = nullptr);
-    KeyTreeView(const QString &stringFilter, const std::shared_ptr<KeyFilter> &keyFilter,
-                AbstractKeyListSortFilterProxyModel *additionalProxy, QWidget *parent,
+    KeyTreeView(const QString &stringFilter,
+                const std::shared_ptr<KeyFilter> &keyFilter,
+                AbstractKeyListSortFilterProxyModel *additionalProxy,
+                QWidget *parent,
                 const KConfigGroup &group);
     ~KeyTreeView() override;
 
@@ -158,4 +160,3 @@ private:
 };
 
 }
-
