@@ -16,7 +16,6 @@
 
 #include <utils/pimpl_ptr.h>
 
-
 class QAbstractItemView;
 
 class KConfigGroup;
@@ -30,13 +29,14 @@ class AbstractKeyListModel;
 class AbstractKeyListSortFilterProxyModel;
 class KeyFilter;
 class KeyListModelInterface;
+class SearchBar;
 
 class TabWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit TabWidget(QWidget *parent = nullptr, Qt::WindowFlags f = {});
-    ~TabWidget();
+    ~TabWidget() override;
 
     void setFlatModel(AbstractKeyListModel *model);
     AbstractKeyListModel *flatModel() const;
@@ -45,7 +45,8 @@ public:
 
     QAbstractItemView *addView(const QString &title = QString(), const QString &keyFilterID = QString(), const QString &searchString = QString());
     QAbstractItemView *addView(const KConfigGroup &group);
-    QAbstractItemView *addTemporaryView(const QString &title = QString(), AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &tabToolTip = QString());
+    QAbstractItemView *
+    addTemporaryView(const QString &title = QString(), AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &tabToolTip = QString());
 
     void loadViews(const KConfig *cfg);
     void saveViews(KConfig *cfg) const;
@@ -57,10 +58,12 @@ public:
     unsigned int count() const;
 
     void createActions(KActionCollection *collection);
-    void connectSearchBar(QObject *sb);
+    void connectSearchBar(SearchBar *sb);
 
     void setMultiSelection(bool on);
 
+    QString stringFilter() const;
+
 public Q_SLOTS:
     void setKeyFilter(const std::shared_ptr<Kleo::KeyFilter> &filter);
     void setStringFilter(const QString &filter);
@@ -79,22 +82,6 @@ Q_SIGNALS:
 private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
-
-    Q_PRIVATE_SLOT(d, void currentIndexChanged(int))
-    Q_PRIVATE_SLOT(d, void slotPageTitleChanged(const QString &))
-    Q_PRIVATE_SLOT(d, void slotPageKeyFilterChanged(const std::shared_ptr<Kleo::KeyFilter> &))
-    Q_PRIVATE_SLOT(d, void slotPageStringFilterChanged(const QString &))
-    Q_PRIVATE_SLOT(d, void slotPageHierarchyChanged(bool))
-    Q_PRIVATE_SLOT(d, void slotRenameCurrentTab())
-    Q_PRIVATE_SLOT(d, void slotNewTab())
-    Q_PRIVATE_SLOT(d, void slotDuplicateCurrentTab())
-    Q_PRIVATE_SLOT(d, void slotCloseCurrentTab())
-    Q_PRIVATE_SLOT(d, void slotMoveCurrentTabLeft())
-    Q_PRIVATE_SLOT(d, void slotMoveCurrentTabRight())
-    Q_PRIVATE_SLOT(d, void slotToggleHierarchicalView(bool))
-    Q_PRIVATE_SLOT(d, void slotExpandAll())
-    Q_PRIVATE_SLOT(d, void slotCollapseAll())
 };
 
 }
-
